(defun C:deformatie ()
	;; Deze functie leest een aantal komma-gescheiden bestanden
	;;   met elk een deformatiemeting op een bepaalde datum,
	;;   en genereert hieruit deformatie-grafieken voor X,Y en voor Z
	;; Per lengteprofiel een aparte tekening, A4 liggend,
	;;   een voorblad A4 staand, en een overzichtstekening met alle punten.

	;; Voor het selekteren van de bestanden wordt gebruik gemaakt van een
	;;   verkenner-achtig selectiescherm, waaruit meerdere bestanden
	;;   tegelijk geselecteerd worden met shift- en/of control- toets.
	;; Hiervoor wordt gebruik gemaakt van DOSLIB, een toevoeging aan AutoCAD

	;; Versie 2020-06-01
	;; Er werd geen vector getekend wanneer het X- of Y-verschil gelijk was aan 0.0. Opgelost met dank aan Kragten

	;; Versie 1.5.1 Datum 14 februari 2018
	;; Vectoren van herplaatste en bijgeplaatste punten in het XY-overzicht gaan nog steeds niet goed.
	;;   en worden daarom niet getekend.

	;; Versie 1.5 Datum : 7 november 2017
	;; Stempel van het Voorblad aangepast. Nu hoeft niets ingevuld te worden.
	;; Tekst "Ministerie van Infrastructuur en Milieu" gewijzigd in "Ministerie van Infrastructuur en Waterstaat

	;; Versie 1.4.5 Datum : 17 oktober 2017
	;; Geen vector tekenen als de XY-cordinaten gelijk zijn
	
	;; Versie 1.4.3 Datum : 25 januari 2016
	;; Vectoren van herplaatste punten worden nu ook getekend.

	;; Versie 1.4 Datum : 1 januari 2016
	;; Aanpassing tekst in stempels

	;; Versie 1.3 Datum: 29 september 2015
	;; LISP-routine stopt onverwachts bij 10 of meer metingen. Opgelost.
	;; In 'overzicht XY Laatste deformatie' vectorpijl gewijzigd
	;; Inlezen van de weertabel naar voren geplaatst.
	;; Bericht na het tekenen van het laatste blad, dat de vector bij herplaatste punten niet wordt getekend

	;; Versie 1.2 Datum: 26 augustus 2014
	;; Complexnaam kan worden ingevoerd in Excel in CEL C1
	;; Extra horizontale lijnen toegevoegd in zowel de XY als de Z-grafieken,
	;;   zodat balk met gegevens en grafiek beter gescheiden zijn.

	;; Versie 1.1 Datum: 19 augustus 2014
	;; DOSlib19.arx toegevoegd voor het gebruik van AutoCAD 2014

	;; Aanpassingen ten opzichte van versie 01-04-2012
	;; Stempels gewijzigd. "Data-ICT-Dienst" vervangen door "Centrale Informatievoorziening".
	;; Papierformaat 1260x297 (6xA4) gewijzigd in 1188x297 (A3.0)


	(setq ligging T)
	;; Wel werkelijke X,Y ligging

	;; Laad het hulpprogramma voor uitvoeren van DOS-commandos
	(get_doslib)

	;; Definieer teksthoogte en font
	(setq thoog 2.0)
	;; Teksthoogte 2 mm

	(command "STYLE" "ROMANS" "ROMANS.SHX" thoog 0.8 0 "N" "N" "N")

	;; Initialiseer systeemvariabelen.
	(setvar "cmdecho" 0)
	;; Geen onnodige tekst over het scherm.
	(setvar "osmode" 0)
	;; Punten kunnen dicht bij elkaar liggen
	(setvar "orthomode" 0)
	;; Niet alleen evenwijdig aan assen
	(setvar "autosnap" 0)
	;; Punten kunnen dicht bij elkaar liggen
	(setvar "dimzin" 0)
	;; Altijd hetzelfde aantal decimalen

	(setvar "MODEMACRO" "Layer $(getvar,clayer)")
	;; Definieer een punt dat altijd op het scherm staat
	(setq ps (getvar "VIEWCTR"))

	;; haal de systeemdatum op
	(setq datumnu (dos_date))
	;; mm-dd-yyyy
	(setq sysdatum (itoa (fix (getvar "CDATE"))))
	;; tijd eraf halen

	;; Haal het pad van de current directory
	(setq nudir (dos_pwdir))
	(setq csvfiles (dos_dir "*.csv"))

	;; Laat bestanden selecteren, met verkenner-achtig scherm
	(setq selfiles (dos_getfilem
                   "Selecteer alle invoerbestanden"
                   nudir
                   "Komma gescheiden bestanden|*.CSV"
                 )
	)
	;; SELFILES bevat het pad, en de geselecteerde bestanden
	(if selfiles
		(progn
		;; Er moeten minstens 2 bestanden geselecteerd zijn,
		;; anders is verwerking zinloos
			(if (< (length selfiles) 3)
				(progn
					(dos_msgbox
					"Er moeten minimaal 2 bestanden worden geselecteerd"
					"Afgebroken"
					1
					5
					)
					(setq selfiles nil)
				)
			)
		)
	)

	(setq nudir (car selfiles))


	;; Laat bestanden selecteren, met verkenner-achtig scherm
	(setq tekfiles (dos_getfilem
                   "Selecteer alle te tekenen bestanden"
                   nudir
                   "Komma gescheiden bestanden|*.CSV"
                 )
	)
	;; TEKFILES bevat het pad, en de geselecteerde bestanden die getekend moeten worden
	(if tekfiles
		(progn
		;; Er moeten minstens 2 files geselecteerd zijn,
		;; anders is verwerking zinloos
			(if (< (length tekfiles) 3)
				(progn
					(dos_msgbox
					"Er moeten minimaal 2 bestanden worden geselecteerd"
					"Afgebroken"
					1
					5
					)
					(setq tekfiles nil)
				)
			)
		)
	)


	;; Lees ook het weerrapport in
	(setq weerfile (getfiled "Selecteer bestand met weerrapport"
                           nudir
                           "TXT"
                           6
                 )
	)


  (if selfiles
    (progn
      ;;(princ "  lezen")
      ;; Initialiseer extrema, alleen lxmin nodig
      (setq lxmin nil)
      (setq maxtxt 0)
      ;; aantalm = het aantal metingen
      (setq aantalm 0)
      ;; Eerste waarde is het pad
      (setq selpad   (car selfiles)
            selfiles (cdr selfiles)
      )
      (setq deflist ()
            datlist ()
            teklist ()
            namen ()
      )
      (setq eerste T)
      (while selfiles

        (setq aantalm (1+ aantalm))

        (setq nufile   (car selfiles)
              selfiles (cdr selfiles)
        )
        (setq filenaam (strcat selpad nufile))
        (setq gfil (open filenaam "r"))
        (setq nulist (lees_csv eerste))
        (setq deflist (cons nulist deflist))
        (setq datlist (cons (car nulist) datlist))
        (if (member nufile tekfiles)
          (progn
            (setq teklist (cons (car nulist) teklist))
            (setq namen (cons datnaam namen))
          )
        )
        (setq eerste nil)
        (close gfil)
      )
      (setq aantalm (- aantalm 1))

      ;; Alle bestanden gelezen, sorteer op datum

      ;; Bestanden sorteren op datum
      (setq datlist (sorteer datlist))
      (setq teklist (sorteer teklist))

      (setq nuldat  (car datlist)
            einddat nuldat
      )

      ;; Zet de nullijst apart, zonder de datum
      (setq defnul (cdr (assoc nuldat deflist)))
      ;; .. en verwijder de nuldatum uit de lijst
      (setq datlist (cdr datlist))

      ;; Splits de punten in profiellijnen, uitgaande van de nullijst
      ;; Maak 2 gesorteerde lijsten, per lengte- en dwarsprofiel
      ;; De dwarsprofielen worden nog niet gebruikt.
      (SORTEER_PR defnul)

      ;; Dit levert als resultaat dwars en langs,
      ;; en de grootste profiel-lengte in maxleng
      ;; Bepaal aan de hand hiervan de lengteschaal van de profielen,


      ;;(princ maxleng)

      (cond
        (
         (< numpt 15)
         (setq formaat "A4"
               bladlengte
                27.7
               bladbreedte
                19.0
         )
         (setq kader "A4 L")
        )

        (
         (< numpt 30)
         (setq formaat "A3"
               bladlengte
                40.0
               bladbreedte
                27.7
         )
         (setq kader "A3")
        )

        (
         (< numpt 40)
         (setq formaat "594x297"
               bladlengte
                57.4
               bladbreedte
                27.7
         )
         (setq kader "594 x 297")
        )

        (
         (< numpt 50)
         (setq formaat "840x297"
               bladlengte
                82.0
               bladbreedte
                27.7
         )
         (setq kader "840 x 297")
        )

        (
         (< numpt 60)
         (setq formaat "840x297"
               bladlengte
                82.0
               bladbreedte
                27.7
         )
         (setq kader "840 x 297")
        )

        (
         (< numpt 101)
         (setq formaat     "1188x297"
               bladlengte  116.8
               bladbreedte 27.7
         )
         (setq kader "1188 x 297")
        )

        (T
         (setq formaat     "1188 x 297"
               bladlengte  116.8
               bladbreedte 27.7
         )
        )
      )



      ;; Vraag of de gebruiker het met deze keuze eens is


      (setq vastcm (+ (/ maxtxt 10.0) maxcm)
            vrijcm (- bladlengte vastcm)
      )
      (cond
        ((< maxleng vrijcm)
         (setq factor 10.0
               schaal 100
         )
        )
        ((< maxleng (* vrijcm 2.0))
         (setq factor 5.0
               schaal 200
         )
        )
        ((< maxleng (* vrijcm 2.5))
         (setq factor 4.0
               schaal 250
         )
        )
        ((< maxleng (* vrijcm 4.0))
         (setq factor 2.5
               schaal 400
         )
        )
        ((< maxleng (* vrijcm 5.0))
         (setq factor 2.0
               schaal 500
         )
        )
        ((< maxleng (* vrijcm 10.0))
         (setq factor 1.0
               schaal 1000
         )
        )
        ((< maxleng (* vrijcm 20.0))
         (setq factor 0.5
               schaal 2000
         )
        )
        ((< maxleng (* vrijcm 50.0))
         (setq factor 0.2
               schaal 5000
         )
        )
        (T
         (setq factor 0.1
               schaal 1000
         )
        )
      )


      ;; Genereer symbolen voor elke herhalingsmeting
      (setq teldat -1
            lendat (length datlist)
      )
      (setq lentek (length teklist))
      (maak_blocks lentek)

      ;; De honderdtallen geven lengteprofielnr aan
      (setq maxprof (car (last langs))
            numprof (length langs)
      )

      ;; Bepaal totaal aantal A4-tekeningen, en bouw tekstdeel
      (setq bladvan (strcat " van "
                            (itoa (setq laatst (+ 3 (* 2 numprof))))
                    )
      )


;; ===============================================================================
;; ===============================================================================
;; Tekenen van het laatste blad (Overzicht Totale XY-deformatie na laatste meting)
;; ===============================================================================
;; ===============================================================================



    ;; ===== Werkelijke ligging
    (setq xmin_lig nil)
    ;; ===== Start voor extrema-bepaling
    ;; ===== Maak de overzichtstekening, met van alle punten de
    ;; ===== Nulligging en de laatste deformatie
    (if ligging
        (progn
        ;; ===== Bepaal de schaal van het overzicht.
        ;; ===== Als gevolg van een scheve ligging
        ;; ===== Hoeft deze niet hetzelfde te zijn als de profielschaal
        (setq dlx     (- lxmax lxmin)
            dly     (- lymax lymin)
            maxmaat (max dlx dly)
            minmaat (min dlx dly)
        )
        ;; ===== Het kader is 25 x 15 cm, welke schaal past daarop?
        ;; ===== Rekening houden met deformatie-overdrijving en titel-ruimte!!
        (setq lfact   factor
			lschaal schaal
        )
        (setq lenkader (* 10 bladlengte)
			brkader  (* 10 bladbreedte)
        )
        ;; ===== Teken de punten op nuldatum, in kunstwerkstelsel
        ;; ===== Werkelijke ligging op de schaal van de profielen
        (setq lennul (length defnul)
			telnul -1
        )
		(while (< (setq telnul (1+ telnul)) lennul)
			(setq pnulid (nth telnul defnul))
			(setq pnul  (cdr pnulid)
				pntid (car pnulid)
			)

			(setq pnumnul (car pnul)
				pcoord  (cdr pnul)
            )
            (setq ptnu (mapcar '(lambda (x) (* x lfact))
				pcoord
                )
            )
            (if xmin_lig
              (progn
                (setq xmin_lig (min xmin_lig (car ptnu)))
                (setq xmax_lig (max xmax_lig (car ptnu)))
                (setq ymin_lig (min ymin_lig (cadr ptnu)))
                (setq ymax_lig (max ymax_lig (cadr ptnu)))
              )
              (progn
                (setq xmin_lig (car ptnu))
                (setq xmax_lig (car ptnu))
                (setq ymin_lig (cadr ptnu))
                (setq ymax_lig (cadr ptnu))
              )
            )
            (command "LAYER" "M" "NUL_LIG" "C" 8 "NUL_LIG" "")
            (command "INSERT" "NUL_METING" ptnu 1 1 0)
            ;; ===== Teken de laatste meting ook
            (setq nulcoor pcoord)
            (setq nudat (last teklist))
            (setq blnam (cadr (assoc nudat datsym)))
            (command "LAYER" "M" blnam "C" 7 blnam "")
            (setq nulist (cdr (assoc (last teklist) deflist)))
            (setq nucoor (cdr (assoc pntid nulist)))
            (if nucoor
              (progn
                (setq pnumm  (car nucoor)
                      nucoor (cdr nucoor)
                )
                (if (equal pnumm pnumnul)
                  ;; ===== De puntnummers van de Nulmeting en de laatste meting zijn gelijk
                  (progn
                    (if (car nucoor)
                      (progn
                        (setq ptekst (strcat " " pnumnul))
                        (command "TEXT" ptnu 0 ptekst)

                        (setq deformatie (mapcar '- nucoor nulcoor))
                        ;; ===== Presenteer de deformatie op overdreven schaal
                        ;; ===== Voorlopig factor 1000
                        (setq tnu
                               (mapcar '+
                                       ptnu
                                       (mapcar '(lambda (x) (* x 1000.0))
                                               deformatie
                                       )
                               )
                        )
                        (setq deftxt (defform deformatie))
                        (setq numtxt (append numtxt (list deftxt)))


                        ;; ===== Geen vector tekenen als de XY-cordinaten gelijk zijn
                        (setq xa (car tnu)
                              ya (cadr tnu)
                              xb (car ptnu)
                              yb (cadr ptnu)
                        )

                        ;; ===== Geen vector tekenen als de XY-cordinaten gelijk zijn
                        ;; /= betekent: niet gelijk aan.
                        (if (or (/= xa xb) (/= ya yb))
							;; Als xa<>xb of ya<>yb dan de vector tekenen.

                            (if (not (equal ptnu tnu))
								(progn
                                ;; ===== Tekenen van de vectorlijn
                                (command "LINE" ptnu tnu "")
                                (setq xmin_lig (min xmin_lig (car tnu)))
                                (setq xmax_lig (max xmax_lig (car tnu)))
                                (setq ymin_lig (min ymin_lig (cadr tnu)))
                                (setq ymax_lig (max ymax_lig (cadr tnu)))


                                ;; ===== Tekenen van de vectorpijl
                                (setq rad (angle ptnu tnu))
                                (setq deg (atof (angtos rad 0 2)))

                                (setq deg (+ 270 deg))

                                (command "INSERT" "pijl" tnu 1.5 1.5 deg)

								)
                            )

                        )
                        
                        (setq plotprof (cons (list nudat tnu) plotprof))
                        (setq pcoord tnu)
                      )
                    )
                  )
                  ;; ===== Als de puntnummers niet gelijk zijn betreft het een
                  ;; ===== Herplaatst of later toegevoegd punt
                  (progn
                    (setq ptekst (strcat " " pnumm))
                    (command "TEXT" ptnu 0 ptekst)

                        (setq deformatie (mapcar '- nucoor nulcoor))
                        ;; ===== Presenteer de deformatie op overdreven schaal
                        ;; ===== Voorlopig factor 1000
                        (setq tnu
                               (mapcar '+
                                       ptnu
                                       (mapcar '(lambda (x) (* x 1000.0))
                                               deformatie
                                       )
                               )
                        )
                        (setq deftxt (defform deformatie))
                        (setq numtxt (append numtxt (list deftxt)))

                        ;; ===== Geen vector tekenen als de cordinaten gelijk zijn
                        (if (not (equal ptnu tnu))
                          (progn
                            ;; ===== Tekenen van de vectorlijn
;;                            (command "LINE" ptnu tnu "")
                            (setq xmin_lig (min xmin_lig (car tnu)))
                            (setq xmax_lig (max xmax_lig (car tnu)))
                            (setq ymin_lig (min ymin_lig (cadr tnu)))
                            (setq ymax_lig (max ymax_lig (cadr tnu)))


                            ;; ===== Tekenen van de vectorpijl
                            (setq rad (angle ptnu tnu))
                            (setq deg (atof (angtos rad 0 2)))

                            (setq deg (+ 270 deg))

;;                            (command "INSERT" "pijl" tnu 1.5 1.5 deg)

                          )
                       )

                  )

                )
              )
            )
          )



          ;; ================================================================
          ;; ===== Bepalen volgnummer van de meting

          (setq volgtekst (itoa aantalm))

          (setq volgstring volgtekst)

          (if (< (strlen volgtekst) 2)
              (setq volgstring (strcat "0" volgtekst))
          )

          ;; =================================================================


          (setq cadnr (strcat omschr "-" volgstring "-ZG"))
          (setq objectcode (strcat omschr "-" volgstring))

          ;; ===== Reserveer extra ruimte voor een behoorlijk kader
          (setq xdif (- xmax_lig xmin_lig))
          (setq ydif (- ymax_lig ymin_lig))
          ;; ===== Bepaal positie van het hierbij behorende kader
          (if (> ydif xdif)
            (progn
              ::
              Staand
              kader,
              met
              titeltje
              onderin
              (setq ygeb (+ ydif 25.0))
              (setq xoff (/ (- brkader xdif) 2.0))
              (setq yoff (/ (- lenkader ygeb) 2.0))

              (setq
                kadp1 (list (- xmin_lig xoff) (- ymin_lig yoff 25.0))
              )
              (setq kadp2 (list (- xmin_lig xoff) (+ ymax_lig yoff)))
              (setq kadp3 (list (+ xmax_lig xoff) (+ ymax_lig yoff)))
              (setq
                kadp4 (list (+ xmax_lig xoff) (- ymin_lig yoff 25.0))
              )

              (command "LAYER" "M" "KADER" "")
              (command "PLINE" kadp1 kadp2 kadp3 kadp4 "C")

              ;; ===== Extra kader voor het afsnijden van het papier en het aanmaken van een plot
              (setq kadp5
                     (list (- xmin_lig xoff 10) (- ymin_lig yoff 35.0))
              )
              (setq
                kadp6 (list (- xmin_lig xoff 10) (+ ymax_lig yoff 10))
              )
              (setq
                kadp7 (list (+ xmax_lig xoff 10) (+ ymax_lig yoff 10))
              )
              (setq kadp8
                     (list (+ xmax_lig xoff 10) (- ymin_lig yoff 35.0))
              )

              (command "LAYER" "M" "Defpoints" "")
              (command "PLINE" kadp5 kadp6 kadp7 kadp8 "C")

              (setq bladnvanm (strcat (itoa laatst) bladvan))
              (command "LAYER" "M" "STEMPEL" "")
              (command "INSERT"       "MDtitel_klein"
                       kadp4          1              ""
                       ""             lschaal        sysdatum
                       objectcode     formaat        bladnvanm
                       kwnaam         "Overzicht XY-deformatie"
                       ""
                      )
              (command "INSERT" "RijkslogoGrafieken" kadp4 1 "" "")

            )
            (progn
              ::
              Liggend
              kader,
              met
              titeltje
              onderin
              (setq ygeb (+ ydif 25.0))
              (setq xoff (/ (- lenkader xdif) 2.0))
              (setq yoff (/ (- brkader ygeb) 2.0))

              (setq
                kadp1 (list (- xmin_lig xoff) (- ymin_lig yoff 25.0))
              )
              (setq p2 (list (- xmin_lig xoff) (+ ymax_lig yoff)))
              (setq p3 (list (+ xmax_lig xoff) (+ ymax_lig yoff)))
              (setq
                kadp4 (list (+ xmax_lig xoff) (- ymin_lig yoff 25.0))
              )

              (command "LAYER" "M" "KADER" "")
              (command "PLINE" kadp1 p2 p3 kadp4 "C")

              (setq kadp5
                     (list (- xmin_lig xoff 10) (- ymin_lig yoff 35.0))
              )
              (setq
                kadp6 (list (- xmin_lig xoff 10) (+ ymax_lig yoff 10))
              )
              (setq
                kadp7 (list (+ xmax_lig xoff 10) (+ ymax_lig yoff 10))
              )
              (setq kadp8
                     (list (+ xmax_lig xoff 10) (- ymin_lig yoff 35.0))
              )

              (command "LAYER" "M" "Defpoints" "")
              (command "PLINE" kadp5 kadp6 kadp7 kadp8 "C")

              (setq bladnvanm (strcat (itoa laatst) bladvan))
              (command "LAYER" "M" "STEMPEL" "")
              (command "INSERT"       "MDtitel_klein"
                       kadp4          1              ""
                       ""             lschaal        sysdatum
                       objectcode     formaat        bladnvanm
                       kwnaam         "Overzicht XY"
                       "Totale deformatie"
                      )
              (command "INSERT" "RijkslogoGrafieken" kadp4 1 "" "")

            )
          )
          (setq xmin_lig (- xmin_lig xdif))
          (setq xmax_lig (+ xmax_lig xdif))
          (setq ymin_lig (- ymin_lig ydif))
        )
      )
      (command "ZOOM" "E")
      (command "ZOOM" "0.9x")
      



;; ====================================================================
;; ====================================================================
;; Tekenen van de XY-Grafieken
;; ====================================================================
;; ====================================================================



      (setq telprof -1)
      (setq lennul (length defnul)
            telnul -1
      )
      ;; ===== Bepaal startpunt voor profielen, afh van ligging
      (if ligging
        (setq xpunt (* 10 (fix (/ (car kadp1) 10)))
              ypunt (- (* 10 (fix (/ (cadr kadp1) 10))) 150.0)
              zpunt 0.0
              plov  kadp1
              prov  kadp4
        )
        (setq xpunt 0.0
              ypunt 0.0
              zpunt 0.0
              plov  (list xpunt ypunt)
        )
      )
      (setq xbasis xpunt
            ybasis ypunt
      )
      (setq tcoord (list xpunt ypunt zpunt))

      (while (< (setq telprof (1+ telprof)) numprof)
        (setq xstart (- xpunt 5.0)
              xeind  xpunt
              xminim xstart
        )
        (setq proflen ()
              min_ydef ypunt
              max_ydef ypunt
        )
        (setq min_zdef zpunt
              max_zdef zpunt
        )
        (setq plotprof ()
              plottxt ()
        )
        (setq sublang (nth telprof langs))
        (setq pronu (car sublang))
        (setq telnum 1
              lensub (length sublang)
        )
        (setq pnu   (nth telnum sublang)
              pntid (car pnu)
        )
        (setq pnu (cdr pnu))
        (setq pnumm (car pnu)
              pcoor (cdr pnu)
        )
        (setq numvorg pnumm
              corvorg pcoor
        )
        ;; ===== Bouw eerste deel subtitel op  Profiel 'van' - 'naar'
        (setq onderw2 (strcat "Profiel " pnumm " - "))

        (setq proflen (cons (list pntid tcoord) proflen))
        (command "LAYER" "M" "NUL_METING" "")
        (command "INSERT" "NUL_METING" tcoord 1 1 0)
        (setq plotprof (cons (list nuldat tcoord) plotprof))
                                        ;        (setq numtxt (list pnumm))
        (setq numtxt ())
        ;; ===== Teken de volgende metingen ook
        (setq teldat -1
              lendat (length datlist)
              datmis nil
        )
        (setq datc tcoord
              nulcoor pcoor
        )

        (while (< (setq teldat (1+ teldat)) lendat)
          ;; ===== Haal de andere metingen uit deflist
          (setq nudat (nth teldat datlist))
          (setq blnam (cadr (assoc nudat datsym)))
          (command "LAYER" "M" blnam "")
          (setq nulist (cdr (assoc (nth teldat datlist) deflist)))
          (setq nucoor (cdr (assoc pntid nulist)))
          (if (cadr nucoor)
            (progn
              (setq pnumm  (car nucoor)
                    nucoor (cdr nucoor)
              )
              (if (equal numvorg pnumm)
                (progn
                  (setq deformatie (mapcar '- nucoor nulcoor))
                  ;; ===== Presenteer de deformatie op overdreven schaal
                  ;; ===== Voorlopig factor 1000

                  (setq tnu (mapcar '+
                                    tcoord
                                    (mapcar '(lambda (x) (* x 1000.0))
                                            deformatie
                                    )
                            )
                  )
                  (if (member nudat teklist)
                    (progn
                      (command "INSERT" blnam tnu 1 1 0)
                      (setq deftxt (defform deformatie))

                      (setq numtxt (append numtxt (list deftxt)))
                    )
                  )
                  (if (not (equal datc tnu))
                    (progn
                      (command "LINE" datc tnu "")
                    )
                  )
                  (setq datmis nil)
                )

                (progn
                  ;; ===== Dit is een nieuwe startmeting
                  ;; ===== Corrigeer de nulcoordinaat om dit punt ook te
                  ;; ===== Blijven gebruiken
                  (setq correctie (mapcar '- nucoor corvorg))
                  (setq nulcoor (mapcar '+ nulcoor correctie))
                  (setq deformatie (mapcar '- nucoor nulcoor))
                  ;; ===== Presenteer de deformatie op overdreven schaal
                  ;; ===== Voorlopig factor 1000
                  (setq tnu (mapcar '+
                                    tcoord
                                    (mapcar '(lambda (x) (* x 1000.0))
                                            deformatie
                                    )
                            )
                  )

                  (command "INSERT" "HERSTELD" tnu 1 1 0)
                  (if (member nudat teklist)
                    (progn
                      (setq deftxt "NULM")

                      (setq numtxt (append numtxt (list deftxt)))
                      ;; ===== Teken het symbool voor hersteld punt,
                      ;; ===== Op dezelfde plaats als de vorige meting
                      (command "INSERT" blnam tnu 1 1 0)
                      (setq datmis nil)

                      (setq herplaatst 1)
                    )
                  )
                )
              )
              (setq numvorg pnumm
                    corvorg nucoor
              )

              (setq plotprof (cons (list nudat tnu) plotprof))
              (setq pcoor nucoor
                    datc  tnu
              )
              (if (< (car tnu) xstart)
                (setq xstart (- (car tnu) 5.0))
              )
              (setq ydef (cadr tnu))
              (if (< ydef min_ydef)
                (setq min_ydef ydef)
                (if (> ydef max_ydef)
                  (setq max_ydef ydef)
                )
              )
              ;; ===== Bepaal ook vast de Z-extrema
              (setq zdef (caddr tnu))
              (if (< zdef min_zdef)
                (setq min_zdef zdef)
                (if (> zdef max_zdef)
                  (setq max_zdef zdef)
                )
              )
            )
            (progn
              (setq datmis T)
              (if (member nudat teklist)
                (progn
                  (setq deftxt "n.g.")
                  (setq numtxt (append numtxt (list deftxt)))
                  (setq plotprof (cons (list nudat nil) plotprof))
                )
              )
            )
          )
        )

        (setq numtxt (cons pnumm numtxt))
        ;; ===== Laatste puntnr
        (setq numtxt (cons pntid numtxt))
        ;; ===== Identificatie
        (setq plottxt (cons numtxt plottxt))
        (while (< (setq telnum (1+ telnum)) lensub)
          (setq pvorg  pnu
                coovor tcoord
          )
          (setq pnu   (nth telnum sublang)
                pntid (car pnu)
          )
          (setq pnu (cdr pnu))
          (setq pnumm (car pnu)
                pcoor (cdr pnu)
          )
          (setq numvorg pnumm
                corvorg pcoor
          )
          (setq afst (* factor (distance (cdr pnu) (cdr pvorg))))
          ;; ===== Afstand tussen de punten minimaal 1 cm
          (if (< afst 10.0)
            (setq afst 10.0)
          )
          (setq xpunt (+ xpunt afst))
          (setq tcoord (list xpunt ypunt zpunt))
          (setq xeind xpunt)
          (setq proflen (cons (list pntid tcoord) proflen))
          (command "LAYER" "M" "NUL_METING" "")
          (command "INSERT" "NUL_METING" tcoord 1 1 0)
                                        ;          (setq numtxt (list pnumm))
          (setq numtxt ())

          ;; Teken de volgende metingen ook
          (setq templist (assoc nuldat plotprof))
          (setq tempnu (append templist (list tcoord)))
          (setq plotprof (subst tempnu templist plotprof))
          (setq teldat -1
                lendat (length datlist)
                datmis nil
          )
          (setq datc    tcoord
                pcoor   (cdr pnu)
                nulcoor pcoor
          )
          (while (< (setq teldat (1+ teldat)) lendat)
            (setq nudat (nth teldat datlist))
            (setq blnam (cadr (assoc nudat datsym)))
            (command "LAYER" "M" blnam "")
            ;; ===== Haal de andere metingen uit deflist
            (setq nulist (cdr (assoc (nth teldat datlist) deflist)))
            (setq nucoor (cdr (assoc pntid nulist)))
            (if (cadr nucoor)
              (progn
                (setq pnumm  (car nucoor)
                      nucoor (cdr nucoor)
                )
                (if (equal numvorg pnumm)
                  (progn
                    (setq deformatie (mapcar '- nucoor nulcoor))
                    ;; ===== Presenteer de deformatie op overdreven schaal
                    ;; ===== Voorlopig factor 1000
                    (setq
                      tnu (mapcar '+
                                  tcoord
                                  (mapcar '(lambda (x) (* x 1000.0))
                                          deformatie
                                  )
                          )
                    )
                    (if (member nudat teklist)
                      (progn
                        (command "INSERT" blnam tnu 1 1 0)
                        (setq deftxt (defform deformatie))
                        (setq numtxt (append numtxt (list deftxt)))
                      )
                    )
                    (if (not (equal datc tnu))
                      (progn
                        (command "LINE" datc tnu "")
                      )
                    )
                    (setq datmis nil)
                  )
                  (progn
                    ;; ===== Dit is een nieuwe startmeting
                    ;; ===== Corrigeer de nulcoordinaat om dit punt ook te
                    ;; ===== Blijven gebruiken
                    (setq correctie (mapcar '- nucoor corvorg))
                    (setq nulcoor (mapcar '+ nulcoor correctie))
                    (setq deformatie (mapcar '- nucoor nulcoor))
                    ;; ===== Presenteer de deformatie op overdreven schaal
                    ;; ===== Voorlopig factor 1000
                    (setq
                      tnu (mapcar '+
                                  tcoord
                                  (mapcar '(lambda (x) (* x 1000.0))
                                          deformatie
                                  )
                          )
                    )
                    (command "INSERT" "HERSTELD" tnu 1 1 0)
                    (if (member nudat teklist)
                      (progn
                        (setq deftxt "NULM")
                        (setq numtxt (append numtxt (list deftxt)))
                        ;; ===== Teken het symbool voor hersteld punt,
                        ;; ===== Op dezelfde plaats als de vorige meting
                        (command "INSERT" blnam tnu 1 1 0)
                        (setq datmis nil)
                      )
                    )
                  )
                )
                (setq numvorg pnumm
                      corvorg nucoor
                )

                (setq templist (assoc nudat plotprof))
                (setq tempnu (append templist (list tnu)))
                (setq plotprof (subst tempnu templist plotprof))
                (setq pcoor nucoor
                      datc  tnu
                )
                (if (< (car tnu) xstart)
                  (setq xstart (- (car tnu) 5.0))
                )
                (if (> (car tnu) xeind)
                  (setq xeind (+ (car tnu) 5.0))
                )
                (setq ydef (cadr tnu))
                (if (< ydef min_ydef)
                  (setq min_ydef ydef)
                  (if (> ydef max_ydef)
                    (setq max_ydef ydef)
                  )
                )
                ;; ===== Bepaal ook vast de Z-extrema
                (setq zdef (caddr tnu))
                (if (< zdef min_zdef)
                  (setq min_zdef zdef)
                  (if (> zdef max_zdef)
                    (setq max_zdef zdef)
                  )
                )

              )
              (progn
                (setq datmis T)
                (if (member nudat teklist)
                  (progn
                    (setq deftxt "n.g.")
                    (setq numtxt (append numtxt (list deftxt)))
                    (setq templist (assoc nudat plotprof))
                    (setq tempnu (append templist (list nil)))
                    (setq plotprof (subst tempnu templist plotprof))
                  )
                )
              )
            )

          )
          (setq numtxt (cons pnumm numtxt))
          (setq numtxt (cons pntid numtxt))
          (setq plottxt (cons numtxt plottxt))
        )
        (setq onderw2 (strcat onderw2 pnumm))

        ;; ===== Teken de horizontale gridlijnen XY-grafiek

        ;; ===== Toegevoegd 26 augustus 2014
        ;; ===== Tekenen extra horizontale lijn, zowel boven als onder 0.0

        (setq max_ydef (+ max_ydef 1.0))
        (setq min_ydef (- min_ydef 1.0))


        (command "LAYER" "M" "REFLIJN" "")
        (setq xeind (+ xeind 5.0))
        (setq yeind (* 10.0 (fix (/ max_ydef 10))))
        (if (< yeind max_ydef)
          (setq yeind (+ yeind 10))
        )
        (setq ystart (* 10.0 (fix (/ min_ydef 10))))
        (if (> ystart min_ydef)
          (setq ystart (- ystart 10))
        )
        (setq ynu ystart
              ps  (list xstart ynu)
              pe  (list xeind ynu)
        )
        (command "LINE" ps pe "")
        (while (< ynu yeind)
          (setq ynu (+ ynu 10)
                ps  (list xstart ynu)
                pe  (list xeind ynu)
          )
          (command "LINE" ps pe "")
        )
        (command "LAYER" "M" "NULLIJN" "")
        (setq ps (list xstart ypunt)
              pe (list xeind ypunt)
        )
        (command "LINE" ps pe "")
        ;; ===== Teken ook de vertikale referentielijnen
        (command "LAYER" "M" "REFLIJN" "")
        (setq xlist (cdr (assoc nuldat plotprof)))
        (while xlist
          (setq xnu   (car (car xlist))
                xlist (cdr xlist)
          )
          (setq ps (list xnu ystart)
                pe (list xnu yeind)
          )
          (command "LINE" ps pe "")
        )
        ;; ===== Teken de teksten erbij
        (setq xlist (reverse proflen))
        (setq ylijn (- ystart thoog thoog))
        (setq ps (list xstart ylijn)
              pe (list xeind ylijn)
        )
        (command "LAYER" "M" "REFLIJN" "")
        (command "LINE" ps pe "")
        (setq lijnen T)
        (while xlist
          (setq ylijn (- ystart thoog thoog))
          (command "LAYER" "M" "NUL_METING" "")
          (setq ytekst (- ystart thoog))
          (setq pnu   (car xlist)
                xlist (cdr xlist)
          )
          (setq pntid (car pnu)
                xnu   (car (cadr pnu))
          )
          (setq numtxt (cdr (assoc pntid plottxt)))
          (setq pnumm  (car numtxt)
                numtxt (cdr numtxt)
          )
          (setq ps (list xnu ytekst))
          (command "TEXT" "J" "MC" ps 0 pnumm)
          (setq dattxt (cdr teklist))
          (while numtxt
            (setq dittxt (car numtxt)
                  numtxt (cdr numtxt)
            )
            (setq nudat  (car dattxt)
                  dattxt (cdr dattxt)
            )
            (setq blnam (cadr (assoc nudat datsym)))
            (command "LAYER" "M" blnam "")
            (setq ytekst (- ylijn thoog))
            (setq ps (list xnu ytekst))
            (command "TEXT" "J" "MC" ps 0 dittxt)
            (if lijnen
              (progn
                (setq ylijn (- ylijn thoog thoog))
                (setq ps (list xstart ylijn)
                      pe (list xeind ylijn)
                )
                (command "LAYER" "M" "REFLIJN" "")
                (command "LINE" ps pe "")
              )
              (setq ylijn (- ylijn thoog thoog))
            )
          )
          (setq lijnen nil)

        )

        ;; ===== Nu nog de meetdatums in de marge
        (setq xtekst (- xstart 5.0)
              ps     (list xtekst ypunt)
        )
        (setq datumt (datkar nuldat))
        (setq teksten (assoc nuldat namen))
        (setq meetnaam (cadr teksten))
        (setq dittxt (strcat meetnaam "  " datumt))

        (command "LAYER" "M" "NUL_METING" "")
        (setq xsy (- xstart 2.0))
        (setq psy (list xsy ypunt))
        (command "INSERT" "NUL_METING" psy "" "" "")
        (command "TEXT" "J" "MR" ps 0 dittxt)

        (setq enttxt (entget (entlast)))
        (setq xtest (car (cdr (assoc 10 enttxt))))
        (if (< xtest xminim)
          (setq xminim xtest)
        )
        (setq dattxt (cdr teklist))
        (setq ytekst (- ystart thoog))
        (setq dittxt "Puntnummers")
        (setq ps (list xtekst ytekst))
        (command "TEXT" "J" "MR" ps 0 dittxt)

        (setq ytekst (- ystart thoog thoog thoog))

        (while dattxt
          (setq nudat  (car dattxt)
                dattxt (cdr dattxt)
          )
          (if (member nudat teklist)
            (progn
              (setq blnam (cadr (assoc nudat datsym)))
              (setq datumt (datkar nudat))
              (setq teksten (assoc nudat namen))
              (setq meetnaam (cadr teksten))
              (setq dittxt (strcat meetnaam "  " datumt))
              (setq ps (list xtekst ytekst))
              (command "LAYER" "M" blnam "")
              (setq psy (list xsy ytekst))
              (command "INSERT" blnam psy "" "" "")
              (command "TEXT" "J" "MR" ps 0 dittxt)
              (setq enttxt (entget (entlast)))
              (setq xtest (car (cdr (assoc 10 enttxt))))
              (if (< xtest xminim)
                (setq xminim xtest)
              )
              (setq ytekst (- ytekst thoog thoog))
            )
          )
        )


        ;; ===== Teken ook kader met titel
        ;; ===== gebruikte extrema (xminim,ylijn) en (xeind,yeind)
        ;; ===== Extra nodig voor titel: 24
        (setq bladkop (itoa (1+ (* 2 (1+ telprof)))))
        (setq bladnvanm (strcat bladkop bladvan))
        (setq xgeb (- xeind xminim)
              ygeb (- yeind ylijn -25.0)
        )
        (setq xoff (/ (- lenkader xgeb) 2.0))
        (setq yoff (/ (- brkader ygeb) 2.0))
        (if (< xoff 0.0)
          (setq xoff 10.0)
        )
        (if (< yoff 0.0)
          (setq yoff 10.0)
        )

        (cond
          ((instr kader "A4 L")

           ;; ===== Binnenkader XY-grafiek

           (setq p1 (list (- xminim xoff) (- ylijn yoff 25.0)))
           (setq p2 (list (- xminim xoff) (+ yeind yoff 0)))
           (setq p3 (list (- xminim xoff -277) (+ yeind yoff 0)))
           (setq p4 (list (- xminim xoff -277) (- ylijn yoff 25.0)))

           (command "LAYER" "M" "KADER" "")
           (command "PLINE" p1 p2 p3 p4 "C")

           ;; ===== Buitenkader XY-grafiek

           (setq p5 (list (- xminim xoff 10) (- ylijn yoff 35.0)))
           (setq p6 (list (- xminim xoff 10) (+ yeind yoff 10)))
           (setq p7 (list (- xminim xoff -287) (+ yeind yoff 10)))
           (setq p8 (list (- xminim xoff -287) (- ylijn yoff 35.0)))
          )
          (T

           (setq p1 (list (- xminim xoff) (- ylijn yoff 25.0)))
           (setq p2 (list (- xminim xoff) (+ yeind yoff)))
           (setq p3 (list (+ xeind xoff) (+ yeind yoff)))
           (setq p4 (list (+ xeind xoff) (- ylijn yoff 25.0)))

           (command "LAYER" "M" "KADER" "")
           (command "PLINE" p1 p2 p3 p4 "C")

           (setq p5 (list (- xminim xoff 10) (- ylijn yoff 35.0)))
           (setq p6 (list (- xminim xoff 10) (+ yeind yoff 10)))
           (setq p7 (list (+ xeind xoff 10) (+ yeind yoff 10)))
           (setq p8 (list (+ xeind xoff 10) (- ylijn yoff 35.0)))
          )
        )

        (command "LAYER" "M" "Defpoints" "")
        (command "PLINE" p5 p6 p7 p8 "C")

        ;; ===== Tekenen van het stempel in de XY-grafieken
        (command "LAYER" "M" "STEMPEL" "")
        (command "INSERT"      "MDtitel_klein"
                 p4            1             ""
                 ""            schaal        sysdatum
                 objectcode    kader         bladnvanm
                 kwnaam        "Deformatieprofiel XY"
                 onderw2
                )
        (command "INSERT" "RijkslogoGrafieken" p4 1 "" "")


        (command "ZOOM" "E")
        (command "ZOOM" "0.9x")


        ;; ===== Houd de minimum Y vast t.b.v. volgende XY-tekening
        (setq ymin_xy (cadr p1))

;; ====================================================================
;; ====================================================================
;; Tekenen van de Z-Grafieken
;; ====================================================================
;; ====================================================================

        ;; Teken nu de Z-deformatie, naast de XY
        (setq proflen (reverse proflen))
        ;; Zoek de deformatie-extrema, min_zdef max_zdef
        (setq numrefz (* 10.0 (fix (/ max_zdef 10))))

        ;;        (while (< (setq telnum (1+ telnum)) lensub)

        ;;        (if (< numrefz max_zdef) (setq numrefz (+ numrefz 10)))
        (if (< numrefz max_zdef)
          (setq numrefz (+ numrefz 10))
        )
        (setq xstart (+ xstart lenkader 50.0)
              xeind  (+ xeind lenkader 50.0)
              yzref  ybasis
              yztop  (+ yzref numrefz)
        )
        ;;De y-waarde van de nulmeting is bepaald, die kunnen we tekenen
        (setq profiel proflen)
        (setq plottxt ()
              plotprof ()
        )
        (command "LAYER" "M" "NUL_METING" "")
        (setq telnum 1
              lensub (length sublang)
        )
        (setq pnu   (nth telnum sublang)
              pntid (car pnu)
        )
        (setq pnu (cdr pnu))
        (setq pnumm (car pnu)
              pcoor (cdr pnu)
        )
        (setq profpos (cadr (assoc pntid profiel)))
        (setq xcoornu (+ (car profpos) lenkader 50.0))
        (setq tcoord (list xcoornu yzref))
        (setq numvorg pnumm
              corvorg pcoor
        )


        (setq onderw2 (strcat "Profiel " pnumm " - "))
        (command "LAYER" "M" "NUL_METING" "")
        (command "INSERT" "NUL_METING" tcoord 1 1 0)
        (setq plotprof (cons (list nuldat tcoord) plotprof))
                                        ;        (setq numtxt (list pnumm))
        (setq numtxt ())
        ;; ===== Teken de volgende metingen ook
        (setq teldat -1
              lendat (length datlist)
              datmis nil
        )
        (setq datc tcoord
              nulcoor pcoor
        )
        (while (< (setq teldat (1+ teldat)) lendat)
          ;; ===== Haal de andere metingen uit deflist
          (setq nudat (nth teldat datlist))
          (setq blnam (cadr (assoc nudat datsym)))
          (command "LAYER" "M" blnam "")
          (setq nulist (cdr (assoc (nth teldat datlist) deflist)))
          (setq nucoor (cdr (assoc pntid nulist)))
          (if nucoor
            (progn
              (setq pnumm  (car nucoor)
                    nucoor (cdr nucoor)
              )
              (if (equal numvorg pnumm)
                (progn
                  (setq deformatie (- (last nucoor) (last nulcoor)))
                  ;; ===== presenteer de deformatie op overdreven schaal
                  ;; ===== voorlopig factor 1000
                  (setq tnu (list xcoornu
                                  (+ yzref (* 1000.0 deformatie))
                            )
                  )
                  (if (member nudat teklist)
                    (progn
                      (command "INSERT" blnam tnu 1 1 0)
                      (setq deftxt (defform deformatie))
                      (setq numtxt (append numtxt (list deftxt)))
                      (setq datmis nil)
                    )
                  )
                )
                (progn
                  ;; ===== Dit is een nieuwe startmeting
                  (setq correctie (mapcar '- nucoor corvorg))
                  (setq nulcoor (mapcar '+ nulcoor correctie))
                  (setq deformatie (- (last nucoor) (last nulcoor)))
                  ;; ===== Presenteer de deformatie op overdreven schaal
                  ;; ===== Voorlopig factor 1000
                  (setq tnu (list xcoornu
                                  (+ yzref (* 1000.0 deformatie))
                            )
                  )
                  (command "INSERT" "HERSTELD" tnu 1 1 0)
                  (if (member nudat teklist)
                    (progn
                      (setq deftxt "NULM")
                      (setq numtxt (append numtxt (list deftxt)))
                      ;; ===== Teken het symbool voor hersteld punt,
                      ;; ===== Op dezelfde plaats als de vorige meting
                      (command "INSERT" blnam tnu 1 1 0)
                      (setq datmis nil)
                    )
                  )
                )
              )
              (setq numvorg pnumm
                    corvorg nucoor
              )
              (setq plotprof (cons (list nudat tnu) plotprof))

              (setq pcoor nucoor
                    datc  tnu
              )
            )
            (progn
              (if (member nudat teklist)
                (progn
                  (setq datmis T)
                  (setq deftxt "n.g.")
                  (setq numtxt (append numtxt (list deftxt)))
                  (setq plotprof (cons (list nudat nil) plotprof))
                  ;;(princ "Eerste punt niet")
                )
              )
            )
          )
        )
        (setq numtxt (cons pnumm numtxt))
        ;; laatste puntnr
        (setq numtxt (cons pntid numtxt))
        ;; identificatie
        (setq plottxt (cons numtxt plottxt))
        (while (< (setq telnum (1+ telnum)) lensub)
          (setq pvorg  pnu
                coovor tcoord
          )
          (setq pnu   (nth telnum sublang)
                pntid (car pnu)
          )
          (setq pnu (cdr pnu))
          (setq pnumm (car pnu)
                pcoor (cdr pnu)
          )
          (setq profpos (cadr (assoc pntid profiel)))
          (setq xcoornu (+ (car profpos) lenkader 50.0))
          (setq tcoord (list xcoornu yzref))
          (setq nulcoor pcoor)
          (setq numvorg pnumm
                corvorg pcoor
          )
          (command "LAYER" "M" "NUL_METING" "")

          (command "INSERT" "NUL_METING" tcoord 1 1 0)
                                        ;          (setq numtxt (list pnumm))
          (setq numtxt ())
          ;;          (command "TEXT" tcoord  0  pnumm)
          ;;          (command "LINE" coovor tcoord "")
          ;; Teken de volgende metingen ook
          (setq templist (assoc nuldat plotprof))
          (setq tempnu (append templist (list tcoord)))
          (setq plotprof (subst tempnu templist plotprof))
          (setq teldat -1
                lendat (length datlist)
                datmis nil
          )
          (setq datc    tcoord
                pcoor   (cdr pnu)
                nulcoor pcoor
          )
          (while (< (setq teldat (1+ teldat)) lendat)
            (setq nudat (nth teldat datlist))
            (setq blnam (cadr (assoc nudat datsym)))
            (command "LAYER" "M" blnam "")
            ;; Haal de andere metingen uit deflist
            (setq nulist (cdr (assoc (nth teldat datlist) deflist)))
            (setq nucoor (cdr (assoc pntid nulist)))
            (if nucoor
              (progn
                (setq pnumm  (car nucoor)
                      nucoor (cdr nucoor)
                )
                (if (equal numvorg pnumm)
                  (progn
                    (setq deformatie (- (last nucoor) (last nulcoor)))
                    ;; presenteer de deformatie op overdreven schaal
                    ;; voorlopig factor 1000
                    (setq tnu (list xcoornu
                                    (+ yzref (* 1000.0 deformatie))
                              )
                    )
                    (if (member nudat teklist)
                      (progn
                        (command "INSERT" blnam tnu 1 1 0)
                        (setq deftxt (defform deformatie))
                        (setq numtxt (append numtxt (list deftxt)))
                        (setq datmis nil)
                      )
                    )
                  )
                  (progn
                    ;; dit is een nieuwe startmeting
                    (setq correctie (mapcar '- nucoor corvorg))
                    (setq nulcoor (mapcar '+ nulcoor correctie))
                    (setq deformatie (- (last nucoor) (last nulcoor)))
                    ;; presenteer de deformatie op overdreven schaal
                    ;; voorlopig factor 1000
                    (setq tnu (list xcoornu
                                    (+ yzref (* 1000.0 deformatie))
                              )
                    )
                    (command "INSERT" "HERSTELD" tnu 1 1 0)
                    (if (member nudat teklist)
                      (progn
                        (setq deftxt "NULM")
                        (setq numtxt (append numtxt (list deftxt)))
                        ;; Teken het symbool voor hersteld punt,
                        ;; op dezelfde plaats als de vorige meting
                        (command "INSERT" blnam tnu 1 1 0)
                        (setq datmis nil)
                      )
                    )
                  )
                )
                (setq numvorg pnumm
                      corvorg nucoor
                )

                (setq templist (assoc nudat plotprof))
                (setq tempnu (append templist (list tnu)))
                (setq plotprof (subst tempnu templist plotprof))
                (setq pcoor nucoor
                      datc  tnu
                )

              )
              (progn
                (setq datmis T)
                (if (member nudat teklist)
                  (progn
                    (setq deftxt "n.g.")
                    (setq numtxt (append numtxt (list deftxt)))
                    (setq templist (assoc nudat plotprof))
                    (setq tempnu (append templist (list nil)))
                    (setq plotprof (subst tempnu templist plotprof))
                    ;;           (princ "  VP niet ")
                  )
                )
              )
            )

          )
          (setq numtxt (cons pnumm numtxt))
          (setq numtxt (cons pntid numtxt))
          (setq plottxt (cons numtxt plottxt))
        )
        (setq onderw2 (strcat onderw2 pnumm))

        (setq plotdump plotprof)
        (while plotprof
          (setq nuprof   (car plotprof)
                plotprof (cdr plotprof)
          )
          (setq nudat  (car nuprof)
                punten (cdr nuprof)
          )
          (if (member nudat teklist)
            (progn
              (setq blnam (cadr (assoc nudat datsym)))
              (command "LAYER" "M" blnam "")
              (setq pnu    (car punten)
                    punten (cdr punten)
              )
              (while punten
                (setq pvor pnu)
                (setq pnu    (car punten)
                      punten (cdr punten)
                )
                (if (and pvor pnu (not (equal pvor pnu)))
                  (command "LINE" pvor pnu "")
                )
              )
            )
          )
        )

        (command "LAYER" "M" "REFLIJN" "")


        ;; ====================================================================
        ;; Teken de horizontale gridlijnen Z-grafiek
        ;; ====================================================================

        ;; Toegevoegd 26 augustus 2014
        ;; Tekenen extra horizontale lijn, zowel boven als onder 0.0

        (setq max_zdef (+ max_zdef 1.0))
        (setq min_zdef (- min_zdef 1.0))



        (setq yeind (* 10.0 (fix (/ max_zdef 10))))
        (if (< yeind max_zdef)
          (setq yeind (+ yeind 10))
        )
        (setq ystart (* 10.0 (fix (/ min_zdef 10))))
        (if (> ystart min_zdef)
          (setq ystart (- ystart 10))
        )
        (setq ystart (+ ystart yzref)
              yeind  (+ yeind yzref)
        )
        (setq ynu ystart
              ps  (list xstart ynu)
              pe  (list xeind ynu)
        )
        (command "LINE" ps pe "")
        (while (< ynu yeind)
          (setq ynu (+ ynu 10)
                ps  (list xstart ynu)
                pe  (list xeind ynu)
          )
          (command "LINE" ps pe "")
        )
        (command "LAYER" "M" "NULLIJN" "")
        (setq ps (list xstart yzref)
              pe (list xeind yzref)
        )
        (command "LINE" ps pe "")

        ;; Teken ook de vertikale referentielijnen
        (command "LAYER" "M" "REFLIJN" "")
        (setq xlist profiel)
        (while xlist
          (setq pxnu  (car xlist)
                xlist (cdr xlist)
          )
          (setq xnu (car (cadr pxnu)))
          (setq xnu (+ xnu lenkader 50.0))
          (setq ps (list xnu ystart)
                pe (list xnu yeind)
          )
          (command "LINE" ps pe "")
        )
        ;; Teken de teksten erbij
        (setq xlist proflen)
        (setq ylijn (- ystart thoog thoog))
        (setq ps (list xstart ylijn)
              pe (list xeind ylijn)
        )
        (command "LAYER" "M" "REFLIJN" "")
        (command "LINE" ps pe "")
        (setq lijnen T)
        (while xlist
          (setq ylijn (- ystart thoog thoog))
          (command "LAYER" "M" "NUL_METING" "")

          (setq ytekst (- ystart thoog))
          (setq pnu   (car xlist)
                xlist (cdr xlist)
          )
          (setq pntid (car pnu))
          (setq xnu (car (cadr pnu)))
          (setq xnu (+ xnu lenkader 50.0))
          (setq numtxt (cdr (assoc pntid plottxt)))
          (setq pnumm  (car numtxt)
                numtxt (cdr numtxt)
          )
          (setq ps (list xnu ytekst))
          (command "TEXT" "J" "MC" ps 0 pnumm)
          (setq dattxt (cdr teklist))
          (setq ytekst (- ystart thoog))
          (setq dittxt "Puntnummers")
          (setq xtekst (- xstart 5.0))
          (setq ps (list xtekst ytekst))
          (command "TEXT" "J" "MR" ps 0 dittxt)


          (while numtxt
            (setq dittxt (car numtxt)
                  numtxt (cdr numtxt)
            )
            (setq nudat  (car dattxt)
                  dattxt (cdr dattxt)
            )
            (setq blnam (cadr (assoc nudat datsym)))
            (command "LAYER" "M" blnam "")
            (setq ytekst (- ylijn thoog))
            (setq ps (list xnu ytekst))
            (command "TEXT" "J" "MC" ps 0 dittxt)
            (if lijnen
              (progn
                (setq ylijn (- ylijn thoog thoog))
                (setq ps (list xstart ylijn)
                      pe (list xeind ylijn)
                )
                (command "LAYER" "M" "REFLIJN" "")
                (command "LINE" ps pe "")
              )
              (setq ylijn (- ylijn thoog thoog))

            )
          )
          (setq lijnen nil)

        )
        ;; Nu nog de meetdatums in de marge
        (setq xtekst (- xstart 5.0)
              ps     (list xtekst yzref)
        )
        (setq datumt (datkar nuldat))
        (setq teksten (assoc nuldat namen))
        (setq meetnaam (cadr teksten))
        (setq dittxt (strcat meetnaam "  " datumt))

        (command "LAYER" "M" "NUL_METING" "")

        (setq xsy (- xstart 2.0))
        (setq psy (list xsy ypunt))

        (command "INSERT" "NUL_METING" psy "" "" "")
        (command "TEXT" "J" "MR" ps 0 dittxt)

        (setq dattxt (cdr teklist))
        (setq ytekst (- ystart thoog thoog thoog))
        (while dattxt
          (setq nudat  (car dattxt)
                dattxt (cdr dattxt)
          )
          (setq blnam (cadr (assoc nudat datsym)))
          (setq datumt (datkar nudat))
          (setq teksten (assoc nudat namen))
          (setq meetnaam (cadr teksten))
          (setq dittxt (strcat meetnaam "  " datumt))
          (setq ps (list xtekst ytekst))
          (command "LAYER" "M" blnam "")
          (setq psy (list xsy ytekst))
          (command "INSERT" blnam psy "" "" "")
          (command "TEXT" "J" "MR" ps 0 dittxt)
          (setq ytekst (- ytekst thoog thoog))
        )
        ;; Teken ook kader met titel
        ;; gebruikte extrema (xminim,ylijn) en (xeind,yztop)
        ;; Extra nodig voor titel: 24
        (setq xminim (+ xminim lenkader 50.0))
        (setq bladkop (itoa (+ 2 (* 2 (1+ telprof)))))
        (setq bladnvanm (strcat bladkop bladvan))
        (setq xgeb (- xeind xminim)
              ygeb (- yztop ylijn -25.0)
        )
        (setq xoff (/ (- lenkader xgeb) 2.0))
        (setq yoff (/ (- brkader ygeb) 2.0))
        (if (< xoff 0.0)
          (setq xoff 10.0)
        )
        (if (< yoff 0.0)
          (setq yoff 10.0)
        )


        (cond
          ((instr kader "A4 L")

           ;;Binnenkader XY-grafiek

           (setq p1 (list (- xminim xoff) (- ylijn yoff 25.0)))
           (setq p2 (list (- xminim xoff) (+ yztop yoff)))
           (setq p3 (list (- xminim xoff -277) (+ yztop yoff)))
           (setq p4 (list (- xminim xoff -277) (- ylijn yoff 25.0)))

           (command "LAYER" "M" "KADER" "")
           (command "PLINE" p1 p2 p3 p4 "C")

           ;;Buitenkader XY-grafiek

           (setq p5 (list (- xminim xoff 10) (- ylijn yoff 35.0)))
           (setq p6 (list (- xminim xoff 10) (+ yztop yoff 10)))
           (setq p7 (list (- xminim xoff -287) (+ yztop yoff 10)))
           (setq p8 (list (- xminim xoff -287) (- ylijn yoff 35.0)))
          )
          (T
           (setq p1 (list (- xminim xoff) (- ylijn yoff 25.0)))
           (setq p2 (list (- xminim xoff) (+ yztop yoff)))
           (setq p3 (list (+ xeind xoff) (+ yztop yoff)))
           (setq p4 (list (+ xeind xoff) (- ylijn yoff 25.0)))

           (command "LAYER" "M" "KADER" "")
           (command "PLINE" p1 p2 p3 p4 "C")

           (setq p5 (list (- xminim xoff 10) (- ylijn yoff 35.0)))
           (setq p6 (list (- xminim xoff 10) (+ yztop yoff 10)))
           (setq p7 (list (+ xeind xoff 10) (+ yztop yoff 10)))
           (setq p8 (list (+ xeind xoff 10) (- ylijn yoff 35.0)))
          )
        )

        (command "LAYER" "M" "Defpoints" "")
        (command "PLINE" p5 p6 p7 p8 "C")

        ;;Tekenen van het stempel in de Z-grafieken
        (command "LAYER" "M" "STEMPEL" "")
        (command "INSERT"      "MDtitel_klein"
                 p4            1             ""
                 ""            schaal        sysdatum
                 objectcode    kader         bladnvanm
                 kwnaam        "Deformatieprofiel Z"
                 onderw2
                )
        (command "INSERT" "RijkslogoGrafieken" p4 1 "" "")


        (command "ZOOM" "E")
        (command "ZOOM" "0.9x")


        ;; Bepaal vast de bovenkant van de volgende tekening
        ;; Bekijk hiervoor ook het XY-kader, dit kan afwijken
        (setq ylaagst (min (cadr p1) ymin_xy))
        (setq yztop (- (* 10 (fix (/ ylaagst 10))) 150.0))



        (setq xpunt  xbasis
              ypunt  yztop
              ybasis yztop
        )
        (setq tcoord (list xpunt ypunt zpunt))
      )

    )
  )

;; ====================================================================
;; ====================================================================
;; Tekenen van het voorblad met ingevulde titel, naast de ligging
;; ====================================================================
;; ====================================================================

  (setq xlbv (+ (car kadp4) 170)
        ylov (cadr kadp4)
        plov (list xlbv ylov)
  )
  (setq xrov (+ xlbv 190)
        ylbv (+ ylov 277)
  )
  (setq plbv (list xlbv ylbv))
  (setq prbv (list xrov ylbv))
  (setq ptit (list xrov ylov))

  (command "LAYER" "M" "KADER" "")
  (command "PLINE" plov ptit prbv plbv "C")

  ;;Extra Kaderrand plaatsen voor het plotten/afsnijden
  (setq p5 (list (+ xlbv -10) (+ ylov -10)))
  (setq p6 (list (+ xrov 10) (+ ylov -10)))
  (setq p7 (list (+ xrov 10) (+ ylbv 10)))
  (setq p8 (list (+ xlbv -10) (+ ylbv 10)))

  (command "LAYER" "M" "Defpoints" "")
  (command "PLINE" p5 p6 p7 p8 "C")


  (setq blad1 (strcat "2" bladvan))


  (command "LAYER" "M" "STEMPEL" "")

;;  (command "INSERT"          "MDTITEL_VOORBLAD"
;;           ptit              1                 ""
;;           ""                "<eigenaar>"     "<beheerder>"
;;           objectcode        complexnaam       kwnaam
;;           objectnaam        "<getekend>"      "<jjjj-mm-dd>"
;;           "<gecontroleerd>" "<jjjj-mm-dd>"    "<vrijgegeven>"
;;           "<jjjj-mm-dd>"    "<Topdesknr>"     " "
;;           " "               cadnr             sysdatum
;;           "Deformatieprofielen XY"            "Deformatieprofielen Z"
;;           "Deformatieschaal 1:1"              laatst
;;           "2"               "A4"
;;          )

  (command "INSERT"          "MDTITEL_VOORBLAD"
           ptit              1                 ""
           ""
           objectcode        complexnaam       kwnaam
           objectnaam
           cadnr             sysdatum
           laatst
           "2"               "A4"
          )




  ;; Plaats de vaste tekst, boven de titel
  (setq pvastt (list (+ xlbv 0) (+ ylov 55)))
  (command "LAYER" "M" "TITELTEKST" "")
  (command "INSERT" "Vaste_tekst" pvastt 1 "" ""
                                              ;;                   "<Peilmerknummer>" "<hoogte>"
                                              ;;                   "<Omschrijving>"
                                              ;;                   "<x-maat (+0000)>" "<y-maat (+0000)>"
                                              ;;                   "<tekeningnummer>"
)

  ;; Bepaal het l.o. punt van de onderste weerregel
  ;;(setq lopunt (* -2.5 10 aantalm))
  ;;  (setq pweer (list (+ xlbv 15) (+ ylov lopunt 160)))
  ;;(setq pweer (list (+ xlbv 15) (+ ylov lopunt 200)))

  (setq lopunt (* -5 aantalm))
  (setq pweer (list (+ xlbv 15) (+ ylov lopunt 240)))

  ;;(setq nudir (car selfiles))

  ;; Lees ook het weerrapport in
;;  (setq weerfile (getfiled "Selecteer bestand met weerrapport"
;;                           nudir
;;                           "TXT"
;;                           6
;;                 )
;;  )
  (if weerfile
    (progn
      (setq wrfil (open weerfile "r"))
      (setq temp_con " %%DC")
      (setq regtel 0)
      (setq weerlist ()
            testlist ()
      )
      ;; Lees van elke meting de gegevens
      (while (setq regel (read-line wrfil))
        (setq regtest (strcase regel))
        (setq regtel (1+ regtel))
        (cond
          ((instr regtest "METING")
           (setq meetntxt (substr regel 8))
           (setq meetnr (atoi meetntxt))
           (setq meetntxt (itoa meetnr))
           ;; eventuele voorloopspaties weg
          )

          ;;2014-04-22

          ((instr regtest "Symbool")
           (setq SYMtxt (substr regel 8))
          )


          ((instr regtest "DATUM")
           (setq DATtxt (substr regel 8)
                 datnum (atoi dattxt)
           )
          )

          ((instr regtest "WINDRICHTING")
           (setq WRICHtxt (substr regel 15))
          )

          ((instr regtest "WINDSTERKTE")
           (setq WSTERtxt (substr regel 14))
          )

          ((instr regtest "BEWOLKING")
           (setq WOLKtxt (substr regel 12))
          )

          ((instr regtest "TEMP. CONSTR")
           (setq TCONtxt (substr regel 16))
          )

          ((instr regtest "TEMP. LUCHT")
           (setq TLUCHtxt (substr regel 14))
          )

          (T
           (if (= regtel 8)
             (progn
               (setq nuweer (list meetntxt    dattxt      wrichtxt
                                  wstertxt    wolktxt     tcontxt
                                  tluchtxt
                                 )
               )

               (setq testlist (cons nuweer weerlist))

               (if (member datnum teklist)
                 (setq weerlist (cons nuweer weerlist))
               )

               (setq meetntxt "")
               (setq dattxt "")
               (setq wrichtxt "")
               (setq wstertxt "")
               (setq wolktxt "")
               (setq tcontxt "")
               (setq tluchtxt "")
               (setq regtel 0)
             )
             (progn
               ;;  Onbekende regel, of extra lege
               (setq regtel (1- regtel))
             )
           )
          )
        )
      )
      (if (= regtel 7)
        (progn
          (setq nuweer (list meetntxt    dattxt      wrichtxt
                             wstertxt    wolktxt     tcontxt
                             tluchtxt
                            )
          )

          (setq testlist (cons nuweer weerlist))
          (if (member datnum teklist)
            (setq weerlist (cons nuweer weerlist))
          )
          (setq meetntxt "")
          (setq dattxt "")
          (setq wrichtxt "")
          (setq wstertxt "")
          (setq wolktxt "")
          (setq tcontxt "")
          (setq tluchtxt "")
          (setq regtel 0)
        )
      )
      ;; Plaats de weerregels
      (setq datsym_weer datsym
            weerregels  weerlist
      )
      (while weerlist
        (setq nuweer   (car weerlist)
              weerlist (cdr weerlist)
        )
        (setq nudats      (car datsym_weer)
              datsym_weer (cdr datsym_weer)
        )
        (setq nulay (cadr nudats))
        (command "LAYER" "M" nulay "")
        (command "INSERT"
                 "WEERREGEL2014"
                 pweer
                 1
                 ""
                 ""
                 (car nuweer)
                 " "
                 (cadr nuweer)
                 (nth 2 nuweer)
                 (nth 3 nuweer)
                 (nth 4 nuweer)
                 (nth 5 nuweer)
                 (nth 6 nuweer)
        )
        (setq pweer (list (car pweer) (+ 5 (cadr pweer))))
      )
      ;; Plaats de titelregel van de weertabel
      (command "LAYER" "M" "TITELLIJN" "")
      (command "INSERT"       "WEERREGEL2014"
               pweer          1              ""
               ""             "Meting"       ""
               "Datum"        "Windrichting" "Windsterkte"
               "Bewolking"    "Temp. Constr."
               "Temp. Lucht"
              )
      (setq pweer (list (car pweer) (+ 5 (cadr pweer))))
      (setq plijn (list (+ 160 (car pweer)) (cadr pweer)))
      (command "LAYER" "M" "TITELLIJN" "")
      (command "LINE" pweer plijn "")
    )
  )
  ;; Teken de legenda


  ;;  (setq xleg (- xrov 130) yleg (- ylbv 20) pleg (list xleg yleg))
  ;;  (command "TEXT" pleg 0 "LEGENDA BIJ DEFORMATIEPROFIELEN")
  ;;  (setq plegsym (list (+ xlbv 10) (+ ylov 250)))
  ;;  (setq plegtxt (list (+ xlbv 20) (+ ylov 250)))
  (setq plegsym (list (+ xlbv 20) (+ ylov 250)))
  (setq plegtxt (list (+ xlbv 30) (+ ylov 250)))

  (setq teldat -1
        lendat (length teklist)
        wissel (1+ (/ lendat 2))
  )

  (setq pweer (list (+ 22 (car pweer)) (- (cadr pweer) 2.5)))

  (while (< (setq teldat (1+ teldat)) lendat)
    ;;    (if (= teldat wissel)
    ;;     (progn
    ;; Ga over op tweede kolom
    ;;       (setq plegsym (list (+ xlbv 70) (+ ylov 250)))
    ;;       (setq plegtxt (list (+ xlbv 80) (+ ylov 250)))
    ;;       (setq plegsym (list (+ xlbv 80) (+ ylov 250)))
    ;;       (setq plegtxt (list (+ xlbv 90) (+ ylov 250)))
    ;;     )
    ;;    )
    (setq nudat (nth teldat teklist))
    (setq blnam (cadr (assoc nudat datsym)))
    (if blnam
      (progn
        ;;    (setq plegsym (list (car plegsym) (- (cadr plegsym) 10)))
        (setq plegsym (list (car plegsym) (- (cadr plegsym) 6)))
        (setq plegtxt (list (car plegtxt) (cadr plegsym)))
        (setq teksten (assoc nudat namen))
        (setq meetnaam (cadr teksten))
        (setq nutekst (strcat "Symbool " meetnaam))
        (command "LAYER" "M" blnam "")
        ;;    (command "INSERT" blnam plegsym 1 1 0)
        (setq pweer (list (car pweer) (- (cadr pweer) 5)))
        (command "INSERT" blnam pweer 1 1 0)
        ;;    (command "TEXT" plegtxt 0  nutekst )
      )
    )

  )
  ;;    (setq plegsym (list (car plegsym) (- (cadr plegsym) 10)))
  (setq plegsym (list (car plegsym) (- (cadr plegsym) 6)))
  (setq plegtxt (list (car plegtxt) (cadr plegsym)))
  (setq plegtxt2 (list (car plegtxt) (- (cadr plegsym) 5)))
  (setq nutekst "Symbool Hersteld punt")
  (command "LAYER" "M" "NUL_METING" "")

  (setq pweer (list (car pweer) (- (cadr pweer) 7.5)))
  (command "INSERT" "HERSTELD" pweer 1 1 0)
  ;;    (command "TEXT" plegtxt 0  nutekst )
  (setq pweer (list (+ 5 (car pweer)) (- (cadr pweer) 0)))
  (command "TEXT" pweer 0 nutekst)
  (setq nutekst "In de kleur van de nieuwe 'nulmeting'")
  (setq pweer (list (car pweer) (- (cadr pweer) 3.5)))
  (command "TEXT" pweer 0 nutekst)


  ;; Definieer teksthoogte en font
  (command "LAYER" "M" "TITELLIJN" "")
  (setq thoog 4.0)
  ;; Teksthoogte 4.0 mm

;;  (command "STYLE" "STANDARD" "STANDARD.SHX" thoog 0.8 0 "N" "N" "N")

  (setq xleg (- xrov 140)
        yleg (- ylbv 20)
        pleg (list xleg yleg)
  )
  (command "TEXT" pleg 0 "LEGENDA BIJ DEFORMATIEGRAFIEKEN")



  (command "ZOOM" "E")
  (command "ZOOM" "0.9x")


    (if herplaatst 1
		(dos_msgbox
              "Bij herplaatste punten wordt de vector niet getekend op het laatste blad. Dit moet achteraf handmatig gebeuren."
              "Let op!!!"
               2
               1
        )

		;; 1 = ! Uitroepteken
		;; 2 = X
		;; 3 = i Informatie
		;; 4 = ? Vraagteken
		;; 5 = X

	)



  ;;(command "LAYER" "M" "NOORDPIJL" "")
  ;;(command "INSERT" "NOORDPIJL")

  (setvar "osmode" 1)
  ;; osnap weer aanzetten
  (setvar "autosnap" 5)
  ;; autosnap setting aanzetten
)

;;=============================================================================
;;=============================================================================
;;=============================================================================

(defun lees_csv (check)
  ;; Deze module leest de komma-gescheiden file in, en slaat de gegevens
  ;; op in een lijst met als eerste item de datum en omschrijving,
  ;; gevolgd door per punt een lijst met: Nummer X Y Z

  ;; !!!! Afhankelijk van de landinstelling wordt dit puntkomma-gescheiden,
  ;; !!!! met komma als decimaalteken. Dan leesmodules aanpassen.

  (setq datum 0.0
        meting_naam
         ""
  )
  (setq regel (read-line gfil))
  ;; eerste regel bevat de titel
  (setq separator (substr regel 1 1))
  ;; komma of puntkomma
  (setq titel (lsstr regel separator))
  ;; Verwijder eventueel omsluitende quotes
  (if (setq pos (instr titel "\""))
    (progn

    )
  )
  (setq complexnaam (lsstr nil separator))

  ;; tweede regel bevat KW-naam en Omschrijving
  (setq regel (read-line gfil))
  (setq titel2 (lsstr regel separator))
  (setq tcomplex (lsstr nil separator))
  (if check
    (progn
      ;; Eerste file die gelezen wordt, houd de titelregels vast
      (setq kwnaam titel2)
      (setq objectnaam tcomplex)
      (setq omschr titel)
    )
    (progn
      ;; Volgende file, controleer of titels gelijk zijn
      (if (or (not (equal kwnaam titel2))
              (not (equal omschr titel))
              (not (equal objectnaam tcomplex))
          )
        (progn
          ;;(princ "Titels niet gelijk, bestanden horen niet bij elkaar")
          (dos_msgbox
            "Titels van de CSV-bestanden niet gelijk. De bestanden horen niet bij elkaar"
            "Afgebroken"
            1
            5
          )

          (exit)
        )
      )
    )
  )

  (setq regel (read-line gfil))
  ;; derde regel bevat meting-naam
  (setq meting_naam (lsstr regel separator))
  (setq regel (read-line gfil))
  ;; vierde regel bevat de datum
  (setq tekst (lsstr regel separator))
  (setq subtitel "")
  (while (< datum 100.0)
    ;; als het een getal is, heb ik de datum
    (if (< (setq datum (atof tekst)) 100.0)
      (progn
        ;; Geen getal, of toch geen datum. Dan omschrijving meting?
        (if (> (strlen tekst) 6)
          (setq meet_txt tekst)
        )
        (setq tekst (lsstr nil separator))
        (if (not tekst)
          (progn
            (setq regel (read-line gfil))
            (setq tekst (lsstr regel separator))
          )
        )
      )
    )
    (setq datumt tekst)
  )
  ;; Datum gelezen, of een ander getal

  ;; Bepaal de benodigde ruimte voor de metingnaam + datum
  (setq dittxt (strcat meting_naam "  " datumt))
  (setq testlijst (list (cons 1 dittxt)))
  (setq txtsize (textbox testlijst))
  (setq txtmin (car (car txtsize))
        txtmax (car (cadr txtsize))
  )
  (setq txtleng (- txtmax txtmin))
  (if (> txtleng maxtxt)
    (setq maxtxt txtleng)
  )

  (setq puntlist ())
  (setq regel (read-line gfil))
  (while regel
    (setq puntnr (lsstr regel separator))
    (if (and puntnr (/= (atoi puntnr) 0))
      (progn
        (setq puntgetal (atoi puntnr))
        (setq xp (lsnumb nil))
        (setq yp (lsnumb nil))
        (setq zp (lsnumb nil))
        (if xp
          (progn
            (if lxmin
              (progn
                (setq lxmin (min lxmin xp)
                      lymin (min lymin yp)
                      lxmax (max lxmax xp)
                      lymax (max lymax yp)
                )
              )
              (progn
                (setq lxmin xp
                      lymin yp
                      lxmax xp
                      lymax yp
                )
              )
            )
          )
        )
        (setq punt (list puntgetal puntnr xp yp zp))
        (setq puntlist (cons punt puntlist))
      )
    )

    (setq regel (read-line gfil))
  )
  (setq datnaam (list datum meting_naam datumt))
  (setq puntlist (cons datum (reverse puntlist)))
)

;;=============================================================================
;;=============================================================================
;;=============================================================================

(defun instr (lang deel / ldeel llang tel ntest)
  ;; funktie instr geeft nil terug als 'deel' geen substring is van lang
  ;; Als deel wel voorkomt, wordt de beginpositie van 'deel' teruggegeven
  (setq ldeel (strlen deel))
  (setq llang (strlen lang))
  (setq ntest (+ (- llang ldeel) 1))
  (setq tel 1
        res nil
  )
  (while (<= tel ntest)
    (if (/= (substr lang tel ldeel) deel)
      (progn
        (setq tel (1+ tel))
      )
      (progn
        (setq res tel)
        (setq tel (1+ ntest))
        ;; forceer einde while
      )
    )
  )
  (setq dum res)
)

;;=============================================================================
;;=============================================================================
;;=============================================================================

(defun SORTEER_PR (lijst / lenlis teller)
  ;; Deze module sorteert de meegegeven lijst op het volledige nummer
  ;; en geeft deze terug in de lijst LANGS
  ;; Tevens wordt gesorteerd op het eindcijfer, naar lijst DWARS
  ;;    De nummmers staan alfanumeriek in de lijst

  ;; Hierbij wordt ervan uitgegaan, dat de invoer op een van deze
  ;; waarden gesorteerd is, zodat de gevonden profielen niet nog eens
  ;; gesorteerd moeten worden.

  (setq lenlis (length lijst))
  (setq langs ()
        dwars ()
  )
  (setq teller -1)
  (while (< (setq teller (1+ teller)) lenlis)
    (setq nupunt (nth teller lijst))
    (setq nummer (car nupunt))
    (setq lanum  (/ nummer 100)
          dwanum (rem nummer 100)
    )
    (if (setq nula (assoc lanum langs))
      (progn
        (setq nulang (append nula (list nupunt)))
        (setq langs (subst nulang nula langs))
      )
      (progn
        (setq nulang (list lanum nupunt))
        (setq langs (append langs (list nulang)))
      )
    )
    (if (setq nudwa (assoc dwanum dwars))
      (progn
        (setq nudwar (append nudwa (list nupunt)))
        (setq dwars (subst nudwar nudwa dwars))
      )
      (progn
        (setq nudwar (list dwanum nupunt))
        (setq dwars (append dwars (list nudwar)))
      )
    )
  )
  ;; Bepaal de lengte van de lengteprofielen
  (setq tlangs langs
        maxleng 0.0
        maxcm 0
        totleng 0.0
        numpt 0
  )
  (while tlangs
    (setq nulang (car tlangs)
          tlangs (cdr tlangs)
    )
    (setq nulang (cdr nulang))
    ;;profielnr eraf
    (if (> (length nulang) numpt)
      (setq numpt (length nulang))
    )
    (setq pnu    (cddr (car nulang))
          nulang (cdr nulang)
    )
    (setq lengte 0.0
          nucm 0
    )
    (while nulang
      (setq pvor pnu)
      (setq pnu    (cddr (car nulang))
            nulang (cdr nulang)
      )
      (setq stap (distance pvor pnu))
      (setq lengte (+ lengte stap))
      (if (< stap 4)
        (setq nucm (1+ nucm))
      )
    )
    (if (> nucm maxcm)
      (setq maxcm nucm)
    )
    (if (> lengte maxleng)
      (setq maxleng lengte)
    )
    (setq totleng (+ totleng lengte))
  )
)

;;=============================================================================
;;=============================================================================
;;=============================================================================

(defun lsstr (_$s1 _$s2 / _$j _$s_l _$temp _$tokn _$tok)
  ;; Dit is een standaard met AutoCAD meegeleverde subroutine,
  ;; die enigszins is aangepast voor deze invoervorm.

  ;; Deze routine leest onderdelen uit een tekststring,
  ;; waarbij het eventuele restant bewaard wordt voor de volgende
  ;; leesopdracht van dezelfde regel.
  ;; Deze routine maakt gebruik van dezelfde regelbuffer als LSNUMB

  (setq *ERRORNO* nil)
  ;; Als er een nieuwe string is meegegeven, bewaar die dan
  (if _$s1
    (setq *STR_TOK* _$s1)
  )

  (if (or (= (type _$s1) 'STR) (= (type *STR_TOK*) 'STR))
    (if (= (type _$s2) 'STR)
      (if (> (setq _$SL (strlen *STR_TOK*)) 0)
        (progn
          ;; Lees de scheidingstekens uit _$s2
          (setq _$j   1
                _$s_l '("\t")
          )
          (repeat (strlen _$s2)
            (setq _$s_l (if _$s_l
                          (append _$s_l (list (substr _$s2 _$j 1)))
                          (list (substr _$s2 _$j 1))
                        )
                  _$j   (1+ _$j)
            )
          )

          ;; Interpreteer de te lezen string
          (setq _$j 1
                _$tok ""
          )
          ;; Skip scheidingstekens aan het begin
          (while (and (<= _$j _$SL)
                      (member (setq ch (substr *STR_TOK* _$j 1)) _$s_l)
                 )
            (setq _$j (1+ _$j)
            )
          )
          ;; Neem over tot scheidingsteken
          (while
            (and (<= _$j _$SL)
                 (not (member (setq ch (substr *STR_TOK* _$j 1)) _$s_l)
                 )
            )
             (setq _$tok (strcat _$tok ch)
                   _$j   (1+ _$j)
             )
          )
          (setq _$temp    *STR_TOK*
                *STR_TOK* (substr _$temp (1+ _$j))
                _$tokn    _$tok
          )
        )
        (setq *STR_TOK* nil)
      )
      (progn
        (setq *ERRORNO* -2)
        nil
      )
    )
    (progn
      (setq *ERRORNO* -1)
      nil
    )
  )
)
;;; End of lsstr defun

;;=============================================================================
;;=============================================================================
;;=============================================================================

(defun lsnumb (_$s1)
  ;; Dit is een standaard met AutoCAD meegeleverde subroutine,
  ;; die enigszins is aangepast voor deze invoervorm.

  ;; Deze routine leest numerieke velden uit een tekststring,
  ;; waarbij het eventuele restant bewaard wordt voor de volgende
  ;; leesopdracht van dezelfde regel.
  ;; Deze routine maakt gebruik van dezelfde regelbuffer als LSSTR
  (setq *ERRORNO* nil)
  (if _$s1
    (setq *STR_TOK* _$s1)
  )
  (if (= (type *STR_TOK*) 'STR)
    (progn
      (setq _$buf *STR_TOK*)
      (setq _$j    1
            _$SL   (1+ (strlen _$buf))
            _$ws   (list " " "\t" separator)
            ;; spatie en tab skippen
            _$xpo  nil
            _$minu ""
            _$int  ""
            _$dot  ""
            _$dec  ""
      )
      ;; definieer hulpvariabele t.b.v. einde regel
      (setq end T)
      (while (< _$j _$SL)
        (setq ch (substr _$buf _$j 1))
        (cond
          ((and (= _$j 1) (= ch separator))
           (setq *STR_TOK* (substr _$buf (1+ _$j)))
           (setq _$j (1+ _$SL))
           ;; geef aan dat geforceerd uit while gesprongen wordt
           (setq end nil)
          )

          ((and (= _$j 1) (member ch _$ws))
           (setq _$buf (substr _$buf (1+ _$j)))
           (setq _$SL (1+ (strlen _$buf)))
          )
          ((and (= _$j 1) (member ch (list "+" "-")))
           (setq _$minu ch)
           (setq _$buf (substr _$buf (1+ _$j)))
           (setq _$SL (1+ (strlen _$buf)))
          )
          ((or (= ch "d") (= ch "D") (= ch "e") (= ch "E"))
           (setq _$xpo ch
                 _$j   (1+ _$j)
           )
          )
          ((and (> (ascii ch) 47) (< (ascii ch) 58))
           ;; cijfer. Is er al een '.' gelezen
           (if _$xpo
             (setq _$xpo (strcat _$xpo ch))
             (if (= _$dot ".")
               (setq _$dec (strcat _$dec ch))
               (setq _$int (strcat _$int ch))
             )
           )
           (setq _$j (1+ _$j))
          )
          ((= ch ".")
           (setq _$dot ch
                 _$j   (1+ _$j)
           )
           ;; als er nog geen cijfer gelezen is, zorg voor 0 voor de punt
           (if (= _$int "")
             (setq _$int "0")
           )
          )
          ((and (/= separator ",") (= ch ","))
           ;; In dit geval is de komma waarschijnlijk het decimaalteken
           (setq _$dot "."
                 _$j   (1+ _$j)
           )
           ;; als er nog geen cijfer gelezen is, zorg voor 0 voor de punt
           (if (= _$int "")
             (setq _$int "0")
           )
          )
          (T
;;; separator gevonden. Sluit proces af
           ;; Als het iets anders dan komma is, skip tot komma
           (while (/= ch separator)
             (setq _$j (1+ _$j))
             (setq ch (substr _$buf _$j 1))
           )
           (setq *STR_TOK* (substr _$buf (1+ _$j)))
           (setq _$j (1+ _$SL))
           ;; geef aan dat geforceerd uit while gesprongen wordt
           (setq end nil)
          )
        )
      )
      ;;
      (if end
        (setq *STR_TOK* nil)
      )

      (if (null _$minu)
        (setq _$minu "")
      )
      (if (null _$int)
        (setq _$int "")
      )
      (if (null _$dec)
        (setq _$dec "")
      )
      (if (null _$dot)
        (setq _$dot "")
      )

      ;; Als er een decimaalpunt gelezen is, altijd minstens 1 decimaal
      (if (= dot ".")
        (if (= dec "")
          (setq dec "0")
        )
      )
      (setq _$numc (strcat _$minu _$int _$dot _$dec))
      (if (/= _$numc "")
        (setq _$num (atof _$numc))
        (setq _$num nil)
      )

    )
    (progn
      (setq *ERRORNO* -1)
      nil
    )
  )
)

;;=============================================================================
;;=============================================================================
;;=============================================================================

(defun sorteer (lijst /)
  ;; Deze routine sorteert een lijst met datums in oplopende volgorde.

  (setq inlen (length lijst))
  (setq uitlist ()
        uittel 0
  )
  (while (< uittel inlen)
    (setq intel -1
          waarde 0
    )
    (while (< (setq intel (1+ intel)) inlen)
      (setq test (nth intel lijst))
      (if test
        (if (> test waarde)
          (setq waarde test)
        )
      )
    )
    (setq lijst (subst nil waarde lijst))
    (setq uitlist (cons waarde uitlist))
    (setq uittel (1+ uittel))
  )
  (setq dum uitlist)
)

;;=============================================================================
;;=============================================================================
;;=============================================================================

(defun get_doslib ()
  ;; Deze routine controleert of het hulpprogramma DOSLIB
  ;; geladen is, en zo ja of het de juiste versie is.
  ;; Indien nog niet geladen, wordt het programma opgezocht,
  ;; en zo mogelijk alsnog geladen.
  (cond
    ((not (null dos_about))
     ;; DOSLIB is al geladen, ik hoef niets te doen
     T
    )

    ;;Controleren aanwezigheid DOSLIB15.ARX
    ((= (atoi (substr (getvar "acadver") 1 2)) 15)
     ;; Nog niet geladen, en ik heb ACAD versie 2000-2002
     (if (findfile "doslib15.arx")
       (setq dum (arxload "doslib15"))
       (if (findfile "doslib2k.arx")
         (setq dum (arxload "doslib2k"))
       )
     )
     (if (null dos_about)
       (progn
         (alert
           (strcat "Systeem incompleet, \ndoslib15.arx ontbreekt,"
                   " \nKopieren vanaf Projecten\\Autocad\\Tools. "
           )
         )
         (exit)
       )
     )
    )


    ;;Controleren aanwezigheid DOSLIB16.ARX
    ((= (atoi (substr (getvar "acadver") 1 2)) 16)
     ;; Nog niet geladen, en ik heb ACAD versie 2004/2005
     (if (findfile "doslib16.arx")
       (setq dum (arxload "doslib16"))
       (if (findfile "doslib2004.arx")
         (setq dum (arxload "doslib2004"))
       )
     )
     (if (null dos_about)
       (progn
         (alert
           (strcat "Systeem incompleet, \ndoslib16.arx ontbreekt,"
                   " \nKopieren vanaf Projecten\\Autocad\\Tools. "
           )
         )
         (exit)
       )
     )
    )




    ;;Controleren aanwezigheid DOSLIB17.ARX
    ((= (atoi (substr (getvar "acadver") 1 2)) 17)
     ;; Nog niet geladen, en ik heb ACAD versie 2007/2008
     (if (findfile "doslib17.arx")
       (setq dum (arxload "doslib17"))
       (if (findfile "doslib2007.arx")
         (setq dum (arxload "doslib2007"))
       )
     )
     (if (null dos_about)
       (progn
         (alert
           (strcat "Systeem incompleet, \ndoslib17.arx ontbreekt,"
                   " \nKopieren vanaf Projecten\\Autocad\\Tools. "
           )
         )
         (exit)
       )
     )
    )




    ;;Controleren aanwezigheid DOSLIB18.ARX
    ((= (atoi (substr (getvar "acadver") 1 2)) 18)
     ;; Nog niet geladen, en ik heb ACAD versie 2010/2011
     (if (findfile "doslib18.arx")
       (setq dum (arxload "doslib18"))
       (if (findfile "doslib2010.arx")
         (setq dum (arxload "doslib2010"))
       )
     )
     (if (null dos_about)
       (progn
         (alert
           (strcat "Systeem incompleet, \ndoslib18.arx ontbreekt,"
                   " \nKopieren vanaf Projecten\\Autocad\\Tools. "
           )
         )
         (exit)
       )
     )
    )



    ;;Controleren aanwezigheid DOSLIB19.ARX
    ((= (atoi (substr (getvar "acadver") 1 2)) 19)
     ;; Nog niet geladen, en ik heb ACAD versie 2014
     (if (findfile "doslib19.arx")
       (setq dum (arxload "doslib19"))
       (if (findfile "doslib2010.arx")
         (setq dum (arxload "doslib2010"))
       )
     )
     (if (null dos_about)
       (progn
         (alert
           (strcat "Systeem incompleet, \ndoslib19.arx ontbreekt,"
                   " \nKopieren vanaf Projecten\\Autocad\\Tools. "
           )
         )
         (exit)
       )
     )
    )



    (T
     ;; Geen versie 15, 16, 17 of 18, dus ik kan dit niet laden
     (terpri)
     (alert
       "Deze functie werkt alleen met AutoCAD versie 2002 tot 2014"
     )
     (exit)
    )

  )
  ;; einde cond DOSLIB
)

;;=============================================================================
;;=============================================================================
;;=============================================================================

(defun defform (coorlis / tx ty)
  ;; Deze module converteert de coordinaatverschillen in meters
  ;; naar tekst, in mm

  ;; In het geval van X.Y deformatie gaat het om een lijst met 2 getallen,
  ;; bij Z-deformatie om een enkel getal.
  ;; ATOM test of het een enkel gegeven betreft, of een lijst
  (if (atom coorlis)
    (progn
      ;; Vermenigvuldig de wwaarden met 1000 om mm te krijgen
      ;; Z deformatie met 1 decimaal
      (setq res (rtos (* 1000.0 coorlis) 2 1))
    )
    (progn
      ;; Vermenigvuldig de wwaarden met 1000 om mm te krijgen
      (setq dx (* 1000.0 (car coorlis)))
      (setq dy (* 1000.0 (cadr coorlis)))
      (if (> dx 0)
        ;; Afronden op hele mm. AutoCAD rondt af richting 0
        ;; Dit vereist dus een correctie van 0 weg
        (setq tx (itoa (fix (+ dx 0.5))))
        (setq tx (itoa (fix (- dx 0.5))))
      )
      (if (> dy 0)
        (setq ty (itoa (fix (+ dy 0.5))))
        (setq ty (itoa (fix (- dy 0.5))))
      )
      (setq res (strcat tx "/" ty))
    )
  )
  (setq dum res)
)

;;=============================================================================
;;=============================================================================
;;=============================================================================

(defun maak_blocks (aantal)
  ;; Deze module maakt de symbolen aan voor de meetpunten,
  ;; het aantal wordt bepaald door het aantal invoerfiles
  ;; Achtereenvolgens cirkel, driehoek, vierkant,

  (setq halfpi  (/ pi 2)
        kwartpi (/ pi 4)
  )
  (setq blocknam (list "NUL_METING"     "METING_1"
                       "METING_2"       "METING_3"
                       "METING_4"       "METING_5"
                       "METING_6"       "METING_7"
                       "METING_8"       "METING_9"
                       "METING_10"      "METING_11"
                       "METING_12"      "METING_13"
                       "METING_14"      "METING_15"
                       "METING_16"      "METING_17"
                       "METING_18"      "METING_19"
                       "METING_20"      "METING_21"
                       "METING_22"      "METING_23"
                       "METING_24"      "METING_25"
                       "METING_26"      "METING_27"
                       "METING_28"      "METING_29"
                       "METING_30"      "METING_31"
                      )

  )
  (command "LAYER" "M" "0" "")
  (setq datsym ()
        datumlist teklist
        bloklist blocknam
  )


  (while datumlist
    (setq dat       (car datumlist)
          datumlist (cdr datumlist)
    )
    (setq bloknu   (car bloklist)
          bloklist (cdr bloklist)
    )
    (setq datsym (cons (list dat bloknu) datsym))
  )

  ;; Nulmeting altijd nodig
  (setq ssblock (ssadd))

  ;;Tekenen van een ** CIRKEL **
  (command "CIRCLE" ps 0.75)
  (ssadd (entlast) ssblock)
  (if (tblsearch "BLOCK" "NUL_METING")
    (command "BLOCK" "NUL_METING" "Y" ps ssblock "")
    (command "BLOCK" "NUL_METING" ps ssblock "")
  )

  (setq p1 (polar ps (+ kwartpi pi) 0.75))
  (setq p3 (polar ps kwartpi 0.75))
  (setq p2 (list (car p1) (cadr p3)))
  (setq p4 (list (car p3) (cadr p1)))

  ;;Tekenen van een ** VIERKANT **
  (command "PLINE" p1 p2 p3 p4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_1")
    (command "BLOCK" "METING_1" "Y" ps ssblock "")
    (command "BLOCK" "METING_1" ps ssblock "")
  )

  (setq hp1 (polar ps 0 0.75))
  (setq hp2 (polar ps halfpi 0.75))
  (setq hp3 (polar ps pi 0.75))
  (setq hp4 (polar ps (+ halfpi pi) 0.75))

  ;;Tekenen van een ** RUIT **
  (command "PLINE" hp1 hp2 hp3 hp4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_2")
    (command "BLOCK" "METING_2" "Y" ps ssblock "")
    (command "BLOCK" "METING_2" ps ssblock "")
  )

  ;;Tekenen van een ** ZANDLOPER (GEDRAAID) **
  (command "PLINE" hp1 hp3 hp2 hp4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_3")
    (command "BLOCK" "METING_3" "Y" ps ssblock "")
    (command "BLOCK" "METING_3" ps ssblock "")
  )

  ;;Tekenen van een ** DRIEHOEK PUNT OMHOOG **
  (command "PLINE" p1 p4 hp2 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_4")
    (command "BLOCK" "METING_4" "Y" ps ssblock "")
    (command "BLOCK" "METING_4" ps ssblock "")
  )

  ;;Tekenen van een ** DRIEHOEK PUNT OMLAAG **
  (command "PLINE" p2 p3 hp4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_5")
    (command "BLOCK" "METING_5" "Y" ps ssblock "")
    (command "BLOCK" "METING_5" ps ssblock "")
  )

  ;;Tekenen van een ** ZANDLOPER STAAND **
  (command "PLINE" p1 p3 p2 p4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_6")
    (command "BLOCK" "METING_6" "Y" ps ssblock "")
    (command "BLOCK" "METING_6" ps ssblock "")
  )

  ;;Tekenen van een ** CIRKEL **
  (command "CIRCLE" ps 0.75)
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_7")
    (command "BLOCK" "METING_7" "Y" ps ssblock "")
    (command "BLOCK" "METING_7" ps ssblock "")
  )

  ;;Tekenen van een ** ZANDLOPER LIGGEND **
  (command "PLINE" p1 p2 p4 p3 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_8")
    (command "BLOCK" "METING_8" "Y" ps ssblock "")
    (command "BLOCK" "METING_8" ps ssblock "")
  )

  ;;Tekenen van een ** DRIEHOEK PUNT LINKS **
  (command "PLINE" p3 p4 hp3 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_9")
    (command "BLOCK" "METING_9" "Y" ps ssblock "")
    (command "BLOCK" "METING_9" ps ssblock "")
  )

  ;;Tekenen van een ** DRIEHOEK PUNT RECHTS **
  (command "PLINE" p1 p2 hp1 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_10")
    (command "BLOCK" "METING_10" "Y" ps ssblock "")
    (command "BLOCK" "METING_10" ps ssblock "")
  )

  ;;Tekenen van een ** VIERKANT **
  (command "PLINE" p1 p2 p3 p4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_11")
    (command "BLOCK" "METING_11" "Y" ps ssblock "")
    (command "BLOCK" "METING_11" ps ssblock "")
  )

  ;;Tekenen van een ** RUIT **
  (command "PLINE" hp1 hp2 hp3 hp4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_12")
    (command "BLOCK" "METING_12" "Y" ps ssblock "")
    (command "BLOCK" "METING_12" ps ssblock "")
  )

  ;;Tekenen van een ** ZANDLOPER (GEDRAAID) **
  (command "PLINE" hp1 hp3 hp2 hp4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_13")
    (command "BLOCK" "METING_13" "Y" ps ssblock "")
    (command "BLOCK" "METING_13" ps ssblock "")
  )

  ;;Tekenen van een ** DRIEHOEK PUNT OMHOOG **
  (command "PLINE" p1 p4 hp2 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_14")
    (command "BLOCK" "METING_14" "Y" ps ssblock "")
    (command "BLOCK" "METING_14" ps ssblock "")
  )

  ;;Tekenen van een ** DRIEHOEK PUNT OMLAAG **
  (command "PLINE" p2 p3 hp4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_15")
    (command "BLOCK" "METING_15" "Y" ps ssblock "")
    (command "BLOCK" "METING_15" ps ssblock "")
  )

  ;;Tekenen van een ** ZANDLOPER STAAND **
  (command "PLINE" p1 p3 p2 p4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_16")
    (command "BLOCK" "METING_16" "Y" ps ssblock "")
    (command "BLOCK" "METING_16" ps ssblock "")
  )

  ;;Tekenen van een ** CIRKEL **
  (command "CIRCLE" ps 0.75)
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_17")
    (command "BLOCK" "METING_17" "Y" ps ssblock "")
    (command "BLOCK" "METING_17" ps ssblock "")
  )

  ;;Tekenen van een ** ZANDLOPER LIGGEND **
  (command "PLINE" p1 p2 p4 p3 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_18")
    (command "BLOCK" "METING_18" "Y" ps ssblock "")
    (command "BLOCK" "METING_18" ps ssblock "")
  )

  ;;Tekenen van een ** DRIEHOEK PUNT LINKS **
  (command "PLINE" p3 p4 hp3 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_19")
    (command "BLOCK" "METING_19" "Y" ps ssblock "")
    (command "BLOCK" "METING_19" ps ssblock "")
  )

  ;;Tekenen van een ** DRIEHOEK PUNT RECHTS **
  (command "PLINE" p1 p2 hp1 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_20")
    (command "BLOCK" "METING_20" "Y" ps ssblock "")
    (command "BLOCK" "METING_20" ps ssblock "")
  )

  ;;Tekenen van een ** VIERKANT **
  (command "PLINE" p1 p2 p3 p4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_21")
    (command "BLOCK" "METING_21" "Y" ps ssblock "")
    (command "BLOCK" "METING_21" ps ssblock "")
  )

  ;;Tekenen van een ** RUIT **
  (command "PLINE" hp1 hp2 hp3 hp4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_22")
    (command "BLOCK" "METING_22" "Y" ps ssblock "")
    (command "BLOCK" "METING_22" ps ssblock "")
  )

  ;;Tekenen van een ** ZANDLOPER (GEDRAAID) **
  (command "PLINE" hp1 hp3 hp2 hp4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_23")
    (command "BLOCK" "METING_23" "Y" ps ssblock "")
    (command "BLOCK" "METING_23" ps ssblock "")
  )

  ;;Tekenen van een ** DRIEHOEK PUNT OMHOOG **
  (command "PLINE" p1 p4 hp2 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_24")
    (command "BLOCK" "METING_24" "Y" ps ssblock "")
    (command "BLOCK" "METING_24" ps ssblock "")
  )

  ;;Tekenen van een ** DRIEHOEK PUNT OMLAAG **
  (command "PLINE" p2 p3 hp4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_25")
    (command "BLOCK" "METING_25" "Y" ps ssblock "")
    (command "BLOCK" "METING_25" ps ssblock "")
  )

  ;;Tekenen van een ** ZANDLOPER STAAND **
  (command "PLINE" p1 p3 p2 p4 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_26")
    (command "BLOCK" "METING_26" "Y" ps ssblock "")
    (command "BLOCK" "METING_26" ps ssblock "")
  )

  ;;Tekenen van een ** CIRKEL **
  (command "CIRCLE" ps 0.75)
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_27")
    (command "BLOCK" "METING_27" "Y" ps ssblock "")
    (command "BLOCK" "METING_27" ps ssblock "")
  )

  ;;Tekenen van een ** ZANDLOPER LIGGEND **
  (command "PLINE" p1 p2 p4 p3 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_28")
    (command "BLOCK" "METING_28" "Y" ps ssblock "")
    (command "BLOCK" "METING_28" ps ssblock "")
  )

  ;;Tekenen van een ** DRIEHOEK PUNT LINKS **
  (command "PLINE" p3 p4 hp3 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_29")
    (command "BLOCK" "METING_29" "Y" ps ssblock "")
    (command "BLOCK" "METING_29" ps ssblock "")
  )

  ;;Tekenen van een ** DRIEHOEK PUNT RECHTS **
  (command "PLINE" p1 p2 hp1 "C")
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "METING_30")
    (command "BLOCK" "METING_30" "Y" ps ssblock "")
    (command "BLOCK" "METING_30" ps ssblock "")
  )

  ;;Tekenen van een ** CIRKEL ** voor een hersteld punt
  (command "CIRCLE" ps 1.5)
  (setq ssblock (ssadd (entlast)))
  (if (tblsearch "BLOCK" "HERSTELD")
    (command "BLOCK" "HERSTELD" "Y" ps ssblock "")
    (command "BLOCK" "HERSTELD" ps ssblock "")
  )

)

;;=============================================================================
;;=============================================================================
;;=============================================================================

(defun datkar (datgetal / dattekst deci)
  (setq dattekst (rtos datgetal 2 1))
  (if (setq deci (instr dattekst "."))
    (setq dattekst (substr dattekst 1 (1- deci)))
  )
  (if (/= (strlen dattekst) 8)
    (progn
      (princ "Datum fout:  ")
      (princ dattekst)
    )
  )
  (setq res dattekst)
)

;;=============================================================================
;;=============================================================================
;;=============================================================================

(defun dxf (k e) (cdr (assoc k e)))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(C:deformatie)
